#  Sky chart program for visual astronomy
#
# Copyright (c) 2008 by David A. Wallace
# Released by the author under GPL license
#
# version 0.11 of 2008.02.18:1400
#
# The catalog data and algorithms herein were gleaned from several sources:
# Practical Astronomy with Your Calculator
#   by Peter Duffett-Smith (3rd ed.)
# Keplerian Elements for Approximate Positions of the Major Planets
#   http://ssd.jpl.nasa.gov/txt/aprx_pos_planets.pdf
# Bright Star Catalog
#
# Names of Stars
#
# Constellation figures
#
#------------------------------------------------------------------------

import pygtk
pygtk.require('2.0')
import gtk
import sys
import gobject
from datetime import *
from time import sleep
from time import time as systime
from math import sin, cos, tan, asin, acos, atan, pi, sqrt, atan2

try:
  from sugar.activity import activity      
  import logging
except: pass
    
# coordinates for my observatory: 71d23m47s W, 42d38m36s N
longitude = -71.3963888889
latitude = 42.64333333

# -----------------------------------------------------------------------
# Keplarian data for planets (J2000.0 epoch coordinates)
#
# FIXME: add data for dwbar, dI and dO
#
#   planet     arg of peri  eccentricity radius (au) inclination    RAAN        mean longitude   delta mean longitude
#   pname         wbar0       E            a            I0            O0             L                dL
planets = [
  ('Mercuy',    77.45779628, 0.20563593,  0.38709927,  7.00497902,  48.33076593, 252.25032350,   149472.67411175),
  ('Venus',    131.60246718, 0.00677672,  0.72333566,  3.39467605,  76.67984255, 181.97909950,    58517.81538729),
  ('Earth',    102.93768193, 0.01671123,  1.00000261, -0.00001531,   0.0,        100.46457166,    35999.37244981),
  ('Mars',     -23.94362959, 0.09339410,  1.52371034,  1.84969142,  49.55953891,  -4.55343205,    19140.30268499),
  ('Jupiter',   14.72847983, 0.04838624,  5.20288700,  1.30439695, 100.47390909,  34.39644051,     3034.74612775),
  ('Saturn',    92.59887831, 0.05386179,  9.53667594,  2.48599187, 113.66242448,  49.95424423,     1222.49362201),
  ('Uranus',   170.95427630, 0.04725744, 19.18916464,  0.77263783,  74.01692503, 313.23810451,      428.48202785),
  ]
sun = ('Sun',  282.93768193, 0.01671123,  1.00000261,  0.0,          0.0,        280.46457166,    35999.37244981)
#       mean longitude lon of peri   lon of Node   Inclination    Eccentricity   radius (km)   Parallax   Offset of Epoch
#           L0             P0            N0             I             e            a              phi0        tau
moon = (318.351648,   36.340410,      318.510107,      5.145396,   0.054900,     384401,          0.9507,    2447891.5)
# obliquity of J2000 epoch is 23.43928 degrees -- we need this value (in radians) for planetary calculations
eps = pi * 23.43928 / 180.0


# -----------------------------------------------------------------------

# Lunar data

# ----------------------------------------------------------------------
#
#	Star Catalog -- Bright Stars (J2000 coordinates)  About 1300 stars
#  Name                                RA            Dec         Mag
star_chart = {                                                          \
  "33 Psc":                      (    0.088917,    -5.707500,   4.61),  \
  "Alpheratz":                   (    0.139806,    29.090556,   2.06),  \
  "Caph":                        (    0.152972,    59.149722,   2.27),  \
  "Kap Scl":                     (    0.155833,   -27.987778,   5.42),  \
  "Eps Phe":                     (    0.156861,   -45.747500,   3.88),  \
  "Gam Oct":                     (    0.167250,   -82.223889,   5.28),  \
  "6 Cet":                       (    0.187750,   -15.468056,   4.89),  \
  "The Scl":                     (    0.195556,   -35.133056,   5.25),  \
  "Algenib":                     (    0.220611,    15.183611,   2.83),  \
  "Chi Peg":                     (    0.243389,    20.206667,   4.80),  \
  "The And":                     (    0.284861,    38.681667,   4.61),  \
  "Sig And":                     (    0.305472,    36.785278,   4.52),  \
  "Iot Cet":                     (    0.323806,    -8.823889,   3.56),  \
  "Zet Tuc":                     (    0.334528,   -64.874722,   4.23),  \
  "Rho And":                     (    0.352028,    37.968611,   5.18),  \
  "Pi Tuc":                      (    0.344167,   -69.625000,   5.51),  \
  "Iot Scl":                     (    0.358667,   -28.981667,   5.18),  \
  "Bet Hyi":                     (    0.429194,   -77.254167,   2.80),  \
  "Ankaa":                       (    0.438056,   -42.306111,   2.39),  \
  "Kap Phe":                     (    0.436722,   -43.680000,   3.94),  \
  "Eta Scl":                     (    0.465472,   -33.007222,   4.81),  \
  "Lam Cas":                     (    0.529556,    54.522222,   4.73),  \
  "Lam Phe":                     (    0.523611,   -48.803611,   4.77),  \
  "Bet Tuc":                     (    0.525750,   -62.958056,   4.37),  \
  "Kap Cas":                     (    0.550000,    62.931667,   4.16),  \
  "The Tuc":                     (    0.556472,   -71.266111,   6.13),  \
  "Zet Cas":                     (    0.616194,    53.896944,   3.66),  \
  "Pi And":                      (    0.614694,    33.719444,   4.36),  \
  "Eps And":                     (    0.642583,    29.311667,   4.37),  \
  "Del And":                     (    0.655472,    30.860833,   3.27),  \
  "Schedar":                     (    0.675139,    56.537222,   2.23),  \
  "Xi Cas":                      (    0.701083,    50.512500,   4.80),  \
  "Mu Phe":                      (    0.688778,   -46.085000,   4.59),  \
  "Xi Phe":                      (    0.696222,   -56.501667,   5.70),  \
  "Pi Cas":                      (    0.724472,    47.024722,   4.94),  \
  "Lam Scl":                     (    0.711917,   -38.463333,   6.06),  \
  "Rho Tuc":                     (    0.707889,   -65.468056,   5.39),  \
  "Diphda":                      (    0.726500,   -17.986667,   2.04),  \
  "Eta Phe":                     (    0.722556,   -57.463056,   4.36),  \
  "Omi Cas":                     (    0.745417,    48.284444,   4.54),  \
  "Phi Cet":                     (    0.736500,   -10.609444,   4.76),  \
  "Zet And":                     (    0.788972,    24.267222,   4.06),  \
  "Achird":                      (    0.818333,    57.815833,   3.44),  \
  "Nu Cas":                      (    0.813917,    50.968333,   4.89),  \
  "Del Psc":                     (    0.811389,     7.585000,   4.43),  \
  "Nu And":                      (    0.830222,    41.078889,   4.53),  \
  "Lam Hyi":                     (    0.809833,   -74.923333,   5.07),  \
  "Rho Phe":                     (    0.844778,   -50.986944,   5.22),  \
  "Lam Tuc":                     (    0.873417,   -69.504444,   6.22),  \
  "Ups Cas":                     (    0.916694,    58.972778,   4.83),  \
  "Cih":                         (    0.945139,    60.716667,   2.47),  \
  "Mu And":                      (    0.945889,    38.499444,   3.87),  \
  "Eta And":                     (    0.953444,    23.417500,   4.42),  \
  "Alp Scl":                     (    0.976778,   -29.357500,   4.31),  \
  "Xi Scl":                      (    1.021750,   -38.916667,   5.59),  \
  "Sig Psc":                     (    1.046972,    31.804444,   5.50),  \
  "Sig Scl":                     (    1.040667,   -31.551944,   5.50),  \
  "Eps Psc":                     (    1.049056,     7.890000,   4.28),  \
  "Ome Phe":                     (    1.033833,   -57.002500,   6.11),  \
  "Psi Psc":                     (    1.094694,    21.473333,   5.34),  \
  "Mu Cas":                      (    1.137889,    54.920278,   5.17),  \
  "Bet Phe":                     (    1.101389,   -46.718611,   3.31),  \
  "Ups Phe":                     (    1.129972,   -41.486944,   5.21),  \
  "Iot Tuc":                     (    1.121861,   -61.775278,   5.37),  \
  "Eta Cet":                     (    1.143167,   -10.182222,   3.45),  \
  "Phi And":                     (    1.158389,    47.241944,   4.25),  \
  "Mirach":                      (    1.162194,    35.620556,   2.06),  \
  "Zet Phe":                     (    1.139750,   -55.245833,   3.92),  \
  "Marfak":                      (    1.185056,    55.149722,   4.33),  \
  "Chi Psc":                     (    1.190889,    21.034722,   4.66),  \
  "Tau Psc":                     (    1.194333,    30.089722,   4.51),  \
  "Phi Psc":                     (    1.229139,    24.583611,   4.65),  \
  "Zet Psc":                     (    1.228861,     7.575278,   5.24),  \
  "Nu Phe":                      (    1.253083,   -45.531389,   4.96),  \
  "Kap Tuc":                     (    1.262806,   -68.876111,   4.86),  \
  "Phi Cas":                     (    1.334694,    58.231667,   4.98),  \
  "Ups Psc":                     (    1.324444,    27.264167,   4.76),  \
  "Xi And":                      (    1.372333,    45.528889,   4.88),  \
  "Psi Cas":                     (    1.432222,    68.130000,   4.74),  \
  "The Cet":                     (    1.400389,    -8.183333,   3.60),  \
  "Ruchbah":                     (    1.430278,    60.235278,   2.68),  \
  "Rho Psc":                     (    1.437583,    19.172222,   5.38),  \
  "Ome And":                     (    1.460944,    45.406667,   4.83),  \
  "Polaris":                     (    2.530194,    89.264167,   2.02),  \
  "Gam Phe":                     (    1.472750,   -43.318333,   3.41),  \
  "Mu Psc":                      (    1.503083,     6.143889,   4.84),  \
  "Eta Psc":                     (    1.524722,    15.345833,   3.62),  \
  "Del Phe":                     (    1.520861,   -49.072778,   3.95),  \
  "Chi Cas":                     (    1.565528,    59.231944,   4.71),  \
  "101 Psc":                     (    1.596222,    14.661389,   6.22),  \
  "Ups And":                     (    1.613278,    41.405556,   4.09),  \
  "Tau Scl":                     (    1.602333,   -29.907500,   5.69),  \
  "Pi Psc":                      (    1.618306,    12.141667,   5.57),  \
  "Chi And":                     (    1.655833,    44.386111,   4.98),  \
  "Achenar":                     (    1.628583,   -57.236667,   0.46),  \
  "Tau And":                     (    1.676333,    40.576944,   4.94),  \
  "Nu Psc":                      (    1.690528,     5.487500,   4.44),  \
  "Phi Per":                     (    1.727667,    50.688611,   4.07),  \
  "Pi Scl":                      (    1.702389,   -32.326944,   5.25),  \
  "Tau Cet":                     (    1.734472,   -15.937500,   3.50),  \
  "Torcularis Septentrionalis":  (    1.756556,     9.157778,   4.26),  \
  "Eps Scl":                     (    1.760778,   -25.052500,   5.31),  \
  "Tau Hyi":                     (    1.689250,   -79.148333,   6.33),  \
  "Chi Cet":                     (    1.826417,   -10.686389,   4.67),  \
  "Zet Cet":                     (    1.857667,   -10.335000,   3.73),  \
  "Segin":                       (    1.906583,    63.670000,   3.38),  \
  "Metallah":                    (    1.884694,    29.578889,   3.41),  \
  "Mesarthim":                   (    1.892167,    19.295833,   4.83),  \
  "Ome Cas":                     (    1.933333,    68.685278,   4.99),  \
  "Xi Psc":                      (    1.892583,     3.187500,   4.62),  \
  "Sharatan":                    (    1.910667,    20.808056,   2.64),  \
  "Psi Phe":                     (    1.894111,   -46.302500,   4.41),  \
  "Phi Phe":                     (    1.906111,   -42.496944,   5.11),  \
  "Iot Ari":                     (    1.955861,    17.817500,   5.10),  \
  "Chi Eri":                     (    1.932639,   -51.608889,   3.70),  \
  "Lam Ari":                     (    1.965472,    23.596111,   4.79),  \
  "Eta Hyi":                     (    1.915583,   -67.647222,   4.69),  \
  "Ups Cet":                     (    2.000083,   -21.077778,   4.00),  \
  "Head of Hydrus":              (    1.979500,   -61.569722,   2.86),  \
  "Sig Hyi":                     (    1.930694,   -78.348333,   6.16),  \
  "Pi For":                      (    2.020750,   -30.001667,   5.35),  \
  "Alrisha":                     (    2.034111,     2.763611,   5.23),  \
  "Eps Tri":                     (    2.049444,    33.283889,   5.50),  \
  "Chi Phe":                     (    2.028444,   -44.713611,   5.14),  \
  "Alamak":                      (    2.065000,    42.329722,   2.26),  \
  "Nu For":                      (    2.074833,   -29.296944,   4.69),  \
  "Kap Ari":                     (    2.109417,    22.648333,   5.03),  \
  "Hamal":                       (    2.119556,    23.462500,   2.00),  \
  "Bet Tri":                     (    2.159056,    34.987222,   3.00),  \
  "Eta Ari":                     (    2.213361,    21.210833,   5.27),  \
  "Xi Cet":                      (    2.216667,     8.846667,   4.37),  \
  "Mu For":                      (    2.215139,   -30.723889,   5.28),  \
  "Del Tri":                     (    2.284222,    34.224167,   4.87),  \
  "Gam Tri":                     (    2.288583,    33.847222,   4.01),  \
  "Pi Hyi":                      (    2.237417,   -67.841667,   5.55),  \
  "The Ari":                     (    2.302083,    19.901111,   5.62),  \
  "Phi Eri":                     (    2.275167,   -51.512222,   3.56),  \
  "Mira":                        (    2.322417,    -2.977500,   3.04),  \
  "Kap For":                     (    2.375722,   -23.816389,   5.20),  \
  "Xi Ari":                      (    2.413611,    10.610556,   5.47),  \
  "Del Hyi":                     (    2.362472,   -68.659444,   4.09),  \
  "Iot Cas":                     (    2.484444,    67.402500,   4.52),  \
  "Rho Cet":                     (    2.432500,   -12.290556,   4.89),  \
  "Lam Hor":                     (    2.414972,   -60.311944,   5.35),  \
  "Kap Hyi":                     (    2.381194,   -73.645833,   5.01),  \
  "Kap Eri":                     (    2.449750,   -47.703889,   4.25),  \
  "Phi For":                     (    2.467139,   -33.811111,   5.14),  \
  "Sig Cet":                     (    2.534778,   -15.244722,   4.75),  \
  "Lam For":                     (    2.551944,   -34.650000,   5.90),  \
  "Ome For":                     (    2.564083,   -28.232500,   4.90),  \
  "Nu Cet":                      (    2.597917,     5.593333,   4.86),  \
  "Iot For":                     (    2.602583,   -30.044722,   5.75),  \
  "Nu Ari":                      (    2.646944,    21.961389,   5.43),  \
  "Mu Hyi":                      (    2.527917,   -79.109444,   5.28),  \
  "Eta Hor":                     (    2.623444,   -52.543056,   5.31),  \
  "Del Cet":                     (    2.658056,     0.328611,   4.07),  \
  "Eps Cet":                     (    2.659389,   -11.872222,   4.84),  \
  "Mu Ari":                      (    2.706111,    20.011667,   5.69),  \
  "Iot Eri":                     (    2.677778,   -39.855556,   4.11),  \
  "The Per":                     (    2.736667,    49.228333,   4.12),  \
  "Zet Hor":                     (    2.677667,   -54.550000,   5.21),  \
  "Kaffaljidhma":                (    2.721667,     3.235833,   3.47),  \
  "Eps Hyi":                     (    2.659833,   -68.266944,   4.11),  \
  "Omi Ari":                     (    2.742472,    15.311667,   5.77),  \
  "Iot Hor":                     (    2.709306,   -50.800278,   5.41),  \
  "Pi Cet":                      (    2.735389,   -13.858611,   4.25),  \
  "Mu Cet":                      (    2.749028,    10.114167,   4.27),  \
  "Angetenar":                   (    2.751722,   -18.572500,   4.47),  \
  "Gam Hor":                     (    2.757639,   -63.704444,   5.74),  \
  "Miram":                       (    2.844944,    55.895556,   3.76),  \
  "Eta For":                     (    2.792694,   -35.550833,   6.51),  \
  "Pi Ari":                      (    2.821528,    17.464167,   5.22),  \
  "Zet Hyi":                     (    2.759056,   -67.616667,   4.84),  \
  "Bet For":                     (    2.818167,   -32.405833,   4.46),  \
  "Gam For":                     (    2.830833,   -24.560278,   6.14),  \
  "Sig Ari":                     (    2.858222,    15.081944,   5.49),  \
  "Nu Hor":                      (    2.817083,   -62.806667,   5.26),  \
  "Tau Per":                     (    2.904306,    52.762500,   3.95),  \
  "Psi For":                     (    2.892889,   -38.436944,   5.92),  \
  "Rho Ari":                     (    2.930139,    18.331667,   5.91),  \
  "Nu Hyi":                      (    2.841250,   -75.066944,   4.75),  \
  "Azha":                        (    2.940472,    -8.898056,   3.89),  \
  "Pi Per":                      (    2.979361,    39.662778,   4.70),  \
  "Eps Ari":                     (    2.986861,    21.340278,   4.63),  \
  "Menkar":                      (    2.995250,     8.907500,   4.70),  \
  "Acamar":                      (    2.971028,   -40.304722,   3.24),  \
  "Zet For":                     (    2.993361,   -25.274167,   5.71),  \
  "Rho Eri":                     (    3.019444,    -7.662778,   5.75),  \
  "Bet Hor":                     (    2.979944,   -64.071389,   4.99),  \
  "Menkar":                      (    3.038000,     4.089722,   2.53),  \
  "Eps For":                     (    3.027139,   -28.091667,   5.89),  \
  "Gam Per":                     (    3.079944,    53.506389,   2.93),  \
  "Gorgonea Tertia":             (    3.086278,    38.840278,   3.39),  \
  "Mu Hor":                      (    3.060222,   -59.737778,   5.11),  \
  "Algol":                       (    3.136139,    40.955556,   2.12),  \
  "Iot Per":                     (    3.151111,    49.613333,   4.05),  \
  "The Hyi":                     (    3.037611,   -71.902500,   5.53),  \
  "Kap Per":                     (    3.158278,    44.857222,   3.80),  \
  "Gorgonea Quarta":             (    3.188167,    39.611667,   4.63),  \
  "Botein":                      (    3.193833,    19.726667,   4.35),  \
  "Fornacis":                    (    3.201194,   -28.986944,   3.87),  \
  "Zet Ari":                     (    3.248361,    21.044444,   4.89),  \
  "Zibal":                       (    3.263889,    -8.819722,   4.80),  \
  "Kap Cet":                     (    3.322694,     3.370278,   4.83),  \
  "Tau Ari":                     (    3.353778,    21.146944,   5.28),  \
  "Zet Ret":                     (    3.296167,   -62.575278,   5.54),  \
  "Mirphak":                     (    3.405389,    49.861111,   1.79),  \
  "Iot Hyi":                     (    3.266000,   -77.388333,   5.52),  \
  "Omi Tau":                     (    3.413556,     9.028889,   3.60),  \
  "Xi Tau":                      (    3.452833,     9.732778,   3.74),  \
  "Chi For":                     (    3.432167,   -35.920833,   6.39),  \
  "Sig Per":                     (    3.509583,    47.995278,   4.36),  \
  "Kap Ret":                     (    3.489639,   -62.937500,   4.72),  \
  "Eps Eri":                     (    3.548833,    -9.458333,   3.73),  \
  "Psi Per":                     (    3.608167,    48.192778,   4.23),  \
  "Tau For":                     (    3.646583,   -27.943056,   6.01),  \
  "Del Per":                     (    3.715417,    47.787500,   3.01),  \
  "Atik":                        (    3.738639,    32.288333,   3.83),  \
  "Del For":                     (    3.704139,   -31.938333,   5.00),  \
  "Nu Per":                      (    3.753222,    42.578611,   3.77),  \
  "Rana":                        (    3.720806,    -9.763333,   3.54),  \
  "Gam Cam":                     (    3.839306,    71.332222,   4.63),  \
  "Pi Eri":                      (    3.769028,   -12.101667,   4.42),  \
  "Alcyone":                     (    3.791417,    24.105000,   2.87),  \
  "Sig For":                     (    3.774278,   -29.338056,   5.90),  \
  "Bet Ret":                     (    3.736667,   -64.806944,   3.85),  \
  "Rho For":                     (    3.798889,   -30.167778,   5.54),  \
  "Menkib":                      (    3.902194,    31.883611,   2.85),  \
  "Gam Hyi":                     (    3.787306,   -74.238889,   3.24),  \
  "Eps Per":                     (    3.964222,    40.010278,   2.89),  \
  "Xi Per":                      (    3.982750,    35.791111,   4.04),  \
  "Zaurak":                      (    3.967167,   -13.508611,   2.95),  \
  "Lam Tau":                     (    4.011333,    12.490278,   3.47),  \
  "Del Ret":                     (    3.979083,   -61.400278,   4.56),  \
  "Nu Tau":                      (    4.052611,     5.989167,   3.91),  \
  "Lam Per":                     (    4.109722,    50.351389,   4.29),  \
  "Gam Ret":                     (    4.014944,   -62.159444,   4.51),  \
  "Iot Ret":                     (    4.021722,   -61.078889,   4.97),  \
  "Psi Tau":                     (    4.116806,    29.001389,   5.23),  \
  "Ome Tau":                     (    4.152778,    19.609167,   5.50),  \
  "Beid":                        (    4.197750,    -6.837500,   4.04),  \
  "Del Hor":                     (    4.180722,   -41.993611,   4.93),  \
  "Mu Per":                      (    4.248306,    48.409444,   4.14),  \
  "Mu Tau":                      (    4.258917,     8.892222,   4.29),  \
  "Alp Hor":                     (    4.233361,   -42.294444,   3.86),  \
  "Alp Ret":                     (    4.240417,   -62.473889,   3.35),  \
  "Gam Dor":                     (    4.267111,   -51.486667,   4.25),  \
  "Hyadum I":                    (    4.329889,    15.627500,   3.65),  \
  "Ups Eri":                     (    4.298250,   -33.798333,   3.56),  \
  "Phi Tau":                     (    4.339250,    27.350833,   4.95),  \
  "Eps Ret":                     (    4.274694,   -59.301944,   4.44),  \
  "Chi Tau":                     (    4.376361,    25.629167,   5.37),  \
  "The Ret":                     (    4.294500,   -63.255556,   5.87),  \
  "Hyadum II":                   (    4.382250,    17.542500,   3.76),  \
  "Xi Eri":                      (    4.394667,    -3.745556,   5.17),  \
  "Kap Tau":                     (    4.422806,    22.293889,   4.22),  \
  "Ups Tau":                     (    4.438472,    22.813611,   4.28),  \
  "Eta Ret":                     (    4.364806,   -63.386389,   5.24),  \
  "Pi Tau":                      (    4.443444,    14.713611,   4.69),  \
  "Ain":                         (    4.476944,    19.180278,   3.53),  \
  "The Tau":                     (    4.476250,    15.962222,   3.84),  \
  "Del Men":                     (    4.299750,   -80.213889,   5.69),  \
  "Del Cae":                     (    4.513917,   -44.953889,   5.07),  \
  "Rho Tau":                     (    4.564139,    14.844444,   4.65),  \
  "Nu Men":                      (    4.349417,   -81.580000,   5.79),  \
  "Aldebaran":                   (    4.598667,    16.509167,   0.85),  \
  "Nu Eri":                      (    4.605306,    -3.352500,   3.93),  \
  "Alp Dor":                     (    4.566611,   -55.045000,   3.27),  \
  "Sig Tau":                     (    4.652556,    15.799722,   5.07),  \
  "Tau Tau":                     (    4.704083,    22.956944,   4.28),  \
  "Alp Cae":                     (    4.676028,   -41.863889,   4.45),  \
  "Bet Cae":                     (    4.700972,   -37.144444,   5.05),  \
  "Lam Pic":                     (    4.712889,   -50.481389,   5.31),  \
  "Mu Eri":                      (    4.758361,    -3.254722,   4.02),  \
  "Kap Dor":                     (    4.739194,   -59.732778,   5.27),  \
  "Zet Cae":                     (    4.797111,   -30.020278,   6.37),  \
  "Mu Men":                      (    4.717750,   -70.931111,   5.54),  \
  "Alp Cam":                     (    4.900833,    66.342778,   4.29),  \
  "Pi Ori":                      (    4.830667,     6.961389,   3.19),  \
  "Omi Ori":                     (    4.875556,    14.250556,   4.74),  \
  "Ome Eri":                     (    4.881583,    -5.452778,   4.39),  \
  "Iot Pic":                     (    4.848667,   -53.461389,   5.61),  \
  "Hassaleh":                    (    4.949889,    33.166111,   2.69),  \
  "Ome Aur":                     (    4.987611,    37.890278,   4.94),  \
  "Bet Cam":                     (    5.056972,    60.442222,   4.03),  \
  "Al Anz":                      (    5.032806,    43.823333,   2.99),  \
  "Haedi":                       (    5.041306,    41.075833,   3.75),  \
  "Psi Eri":                     (    5.023972,    -7.173889,   4.81),  \
  "Iot Tau":                     (    5.051583,    21.590000,   4.64),  \
  "Eta Men":                     (    4.919778,   -74.936944,   5.47),  \
  "Eta Aur":                     (    5.108583,    41.234444,   3.17),  \
  "Eta Pic":                     (    5.046833,   -49.151389,   5.38),  \
  "Gam Cae":                     (    5.073444,   -35.483333,   4.55),  \
  "Eps Lep":                     (    5.091028,   -22.371111,   3.19),  \
  "Cursa":                       (    5.130833,    -5.086389,   2.79),  \
  "Zet Dor":                     (    5.091833,   -57.472778,   4.72),  \
  "Bet Men":                     (    5.045278,   -71.314444,   5.31),  \
  "Lam Eri":                     (    5.152444,    -8.754167,   4.27),  \
  "Mu Aur":                      (    5.223806,    38.484444,   4.86),  \
  "Iot Lep":                     (    5.204972,   -11.869167,   4.45),  \
  "Rho Ori":                     (    5.221528,     2.861111,   4.46),  \
  "Mu Lep":                      (    5.215528,   -16.205556,   3.31),  \
  "Kap Lep":                     (    5.220528,   -12.941389,   4.36),  \
  "Capella":                     (    5.278167,    45.998056,   0.08),  \
  "Rigel":                       (    5.242306,    -8.201667,   0.12),  \
  "Xi Men":                      (    4.980806,   -82.470556,   5.85),  \
  "Lam Aur":                     (    5.319028,    40.099167,   4.71),  \
  "Tau Ori":                     (    5.293444,    -6.844444,   3.60),  \
  "Omi Col":                     (    5.291417,   -34.895278,   4.83),  \
  "The Dor":                     (    5.229278,   -67.185278,   4.83),  \
  "Rho Aur":                     (    5.363444,    41.804444,   5.23),  \
  "Lam Lep":                     (    5.326250,   -13.176667,   4.29),  \
  "Nu Lep":                      (    5.333083,   -12.315556,   5.30),  \
  "Zet Pic":                     (    5.322806,   -50.606111,   5.45),  \
  "Sig Aur":                     (    5.410889,    37.385556,   4.99),  \
  "Eta Ori":                     (    5.407944,    -2.396944,   3.36),  \
  "Psi Ori":                     (    5.412444,     1.846389,   4.95),  \
  "Bellatrix":                   (    5.418861,     6.349722,   1.64),  \
  "Al Nath":                     (    5.438194,    28.607500,   1.65),  \
  "Kap Pic":                     (    5.372806,   -56.134444,   6.11),  \
  "Phi Aur":                     (    5.460806,    34.475833,   5.07),  \
  "The Pic":                     (    5.412833,   -52.316389,   6.27),  \
  "Nihal":                       (    5.470750,   -20.759444,   2.84),  \
  "Lam Dor":                     (    5.438694,   -58.912500,   5.14),  \
  "Chi Aur":                     (    5.545472,    32.191944,   4.76),  \
  "Mintaka":                     (    5.533472,    -0.284444,   6.85),  \
  "Ups Ori":                     (    5.532167,    -7.301389,   4.62),  \
  "Eps Col":                     (    5.520194,   -35.470556,   3.87),  \
  "Arneb":                       (    5.545500,   -17.822222,   2.58),  \
  "Phi Ori":                     (    5.580333,     9.489444,   4.41),  \
  "Meissa":                      (    5.585639,     9.934167,   3.54),  \
  "The Ori":                     (    5.587750,    -5.387222,   6.73),  \
  "Nair al Saif":                (    5.590556,    -5.910000,   2.77),  \
  "Alnilam":                     (    5.603556,    -1.201944,   1.70),  \
  "Zet Tau":                     (    5.627417,    21.142500,   3.00),  \
  "Bet Dor":                     (    5.560417,   -62.489722,   3.76),  \
  "Nu Col":                      (    5.621250,   -27.871389,   6.16),  \
  "Sig Ori":                     (    5.645778,    -2.600000,   3.81),  \
  "Ome Ori":                     (    5.653083,     4.121389,   4.57),  \
  "Alnitak":                     (    5.679306,    -1.942778,   2.05),  \
  "Gam Men":                     (    5.531361,   -76.341111,   5.19),  \
  "Phact":                       (    5.660806,   -34.074167,   2.64),  \
  "Omi Aur":                     (    5.765000,    49.826389,   5.47),  \
  "Gam Lep":                     (    5.741056,   -22.448333,   3.60),  \
  "Iot Men":                     (    5.593417,   -78.820833,   6.05),  \
  "Tau Aur":                     (    5.819583,    39.181111,   4.52),  \
  "Mu Col":                      (    5.766639,   -32.306389,   5.17),  \
  "Zet Lep":                     (    5.782583,   -14.821944,   3.55),  \
  "Saiph":                       (    5.795944,    -9.669722,   2.06),  \
  "Ups Aur":                     (    5.850667,    37.305556,   4.74),  \
  "Nu Aur":                      (    5.858167,    39.148611,   3.97),  \
  "Del Dor":                     (    5.746222,   -65.735556,   4.35),  \
  "Bet Pic":                     (    5.788083,   -51.066389,   3.85),  \
  "Pi Men":                      (    5.619389,   -80.469167,   5.65),  \
  "Xi Aur":                      (    5.914111,    55.706944,   4.99),  \
  "Del Lep":                     (    5.855361,   -20.879167,   3.81),  \
  "Wezn":                        (    5.849333,   -35.768333,   3.12),  \
  "Gam Pic":                     (    5.830472,   -56.166667,   4.51),  \
  "Chi Ori":                     (    5.906361,    20.276111,   4.41),  \
  "Lam Col":                     (    5.885250,   -33.801389,   4.87),  \
  "Betelgeuse":                  (    5.919528,     7.406944,   0.50),  \
  "Lam Men":                     (    5.796694,   -72.702222,   6.53),  \
  "Eps Dor":                     (    5.831556,   -66.901111,   5.11),  \
  "Del Aur":                     (    5.992111,    54.284722,   3.72),  \
  "Eta Lep":                     (    5.940083,   -14.167778,   3.71),  \
  "Xi Col":                      (    5.924972,   -37.120833,   4.97),  \
  "Menkalinan":                  (    5.992139,    44.947500,   1.90),  \
  "Pi Aur":                      (    5.998917,    45.936944,   4.26),  \
  "Sig Col":                     (    5.939139,   -31.382500,   5.50),  \
  "The Aur":                     (    5.995361,    37.212500,   2.62),  \
  "Gam Col":                     (    5.958944,   -35.283333,   4.36),  \
  "Eta Col":                     (    5.985778,   -42.815278,   3.96),  \
  "Mu Ori":                      (    6.039722,     9.647500,   4.12),  \
  "Kap Men":                     (    5.837972,   -79.361389,   5.47),  \
  "The Lep":                     (    6.102583,   -14.935278,   4.67),  \
  "Nu Ori":                      (    6.126194,    14.768333,   4.42),  \
  "Pi Col":                      (    6.111389,   -42.298611,   6.12),  \
  "The Col":                     (    6.125444,   -37.253056,   5.02),  \
  "Eta Dor":                     (    6.102611,   -66.039722,   5.71),  \
  "Xi Ori":                      (    6.199000,    14.208889,   4.48),  \
  "Del Pic":                     (    6.171639,   -54.968611,   4.81),  \
  "Propus":                      (    6.247944,    22.506667,   3.28),  \
  "Kap Aur":                     (    6.256306,    29.498056,   4.35),  \
  "Nu Dor":                      (    6.145611,   -68.843333,   5.06),  \
  "Gam Mon":                     (    6.247583,    -6.274722,   3.98),  \
  "Kap Col":                     (    6.275861,   -35.140556,   4.37),  \
  "Alp Men":                     (    6.170667,   -74.753056,   5.09),  \
  "Furud":                       (    6.338556,   -30.063333,   3.02),  \
  "Mu Gem":                      (    6.382667,    22.513611,   2.88),  \
  "Psi Aur":                     (    6.414972,    49.288056,   4.91),  \
  "Murzim":                      (    6.378333,   -17.955833,   1.98),  \
  "Del Col":                     (    6.368556,   -33.436389,   3.85),  \
  "Eps Mon":                     (    6.396139,     4.592778,   4.44),  \
  "Nu Pic":                      (    6.382167,   -56.370000,   5.61),  \
  "Canopus":                     (    6.399194,   -52.695833,  -0.72),  \
  "Nu Gem":                      (    6.482722,    20.212222,   4.15),  \
  "Pi Dor":                      (    6.377278,   -69.984167,   5.56),  \
  "Bet Mon":                     (    6.480278,    -7.032778,   4.60),  \
  "Lam CMa":                     (    6.469472,   -32.580000,   4.48),  \
  "Xi CMa":                      (    6.530917,   -23.418333,   4.33),  \
  "Mu Pic":                      (    6.532889,   -58.754167,   5.70),  \
  "Alhena":                      (    6.628528,    16.399167,   1.93),  \
  "Nu CMa":                      (    6.606333,   -18.660000,   5.70),  \
  "Nu Pup":                      (    6.629361,   -43.196111,   3.17),  \
  "Mebsuta":                     (    6.732194,    25.131111,   2.98),  \
  "Xi Gem":                      (    6.754833,    12.895556,   3.36),  \
  "Sirius":                      (    6.752472,   -16.716111,  -1.46),  \
  "Kap CMa":                     (    6.830694,   -32.508611,   3.96),  \
  "The Gem":                     (    6.879806,    33.961111,   3.60),  \
  "Alp Pic":                     (    6.803167,   -61.941389,   3.27),  \
  "Tau Pup":                     (    6.832278,   -50.614722,   2.93),  \
  "Zet Men":                     (    6.667417,   -80.813611,   5.64),  \
  "The CMa":                     (    6.903167,   -12.038611,   4.07),  \
  "Omi CMa":                     (    6.902194,   -24.183889,   3.87),  \
  "Pi CMa":                      (    6.927056,   -20.136389,   4.68),  \
  "Mu CMa":                      (    6.935167,   -14.043611,   5.00),  \
  "Iot CMa":                     (    6.935611,   -17.054167,   4.37),  \
  "Iot Vol":                     (    6.857500,   -70.963333,   5.40),  \
  "Adharaz":                     (    6.977083,   -28.972222,   1.50),  \
  "Ome Gem":                     (    7.040222,    24.215278,   5.18),  \
  "Sig CMa":                     (    7.028639,   -27.934722,   3.47),  \
  "Mekbuda":                     (    7.068472,    20.570278,   3.79),  \
  "Muliphen":                    (    7.062639,   -15.633333,   4.12),  \
  "The Men":                     (    6.942889,   -79.420278,   5.45),  \
  "Wezen":                       (    7.139861,   -26.393333,   1.84),  \
  "Tau Gem":                     (    7.185667,    30.245278,   4.41),  \
  "Del Mon":                     (    7.197750,    -0.492778,   4.15),  \
  "Gam Vol":                     (    7.145056,   -70.497222,   5.69),  \
  "Ome CMa":                     (    7.246861,   -26.772778,   3.85),  \
  "Lam Gem":                     (    7.301556,    16.540278,   3.58),  \
  "Pi Pup":                      (    7.285722,   -37.097500,   2.70),  \
  "Wasat":                       (    7.335389,    21.982222,   3.53),  \
  "Tau CMa":                     (    7.311778,   -24.954167,   4.40),  \
  "Del Vol":                     (    7.280500,   -67.957222,   3.98),  \
  "Propus":                      (    7.428778,    27.798056,   3.79),  \
  "Aludra":                      (    7.401583,   -29.303056,   2.45),  \
  "Eps CMi":                     (    7.427472,     9.276111,   4.99),  \
  "Gomeisa":                     (    7.452500,     8.289444,   2.90),  \
  "Eta CMi":                     (    7.467250,     6.941944,   5.25),  \
  "Rho Gem":                     (    7.485194,    31.784444,   4.18),  \
  "Gam CMi":                     (    7.469389,     8.925556,   4.32),  \
  "Sig Pup":                     (    7.487167,   -43.301389,   3.25),  \
  "Del CMi":                     (    7.534972,     1.914444,   5.25),  \
  "Castor":                      (    7.576667,    31.888611,   2.88),  \
  "Ups Gem":                     (    7.598694,    26.895833,   4.06),  \
  "Eps Men":                     (    7.427222,   -79.094167,   5.53),  \
  "Omi Gem":                     (    7.652750,    34.584167,   4.90),  \
  "Procyon":                     (    7.655028,     5.225000,   0.38),  \
  "Alp Mon":                     (    7.687444,    -9.551111,   3.93),  \
  "Sig Gem":                     (    7.721861,    28.883611,   4.28),  \
  "Kap Gem":                     (    7.740778,    24.398056,   3.57),  \
  "Pollux":                      (    7.755250,    28.026111,   1.14),  \
  "Pi Gem":                      (    7.791750,    33.415556,   5.14),  \
  "Zet Vol":                     (    7.697000,   -72.606111,   3.95),  \
  "Omi Pup":                     (    7.801444,   -25.937222,   4.50),  \
  "Xi Pup":                      (    7.821583,   -24.859722,   3.34),  \
  "Zet CMi":                     (    7.861667,     1.766944,   5.14),  \
  "Phi Gem":                     (    7.891611,    26.765833,   4.97),  \
  "Chi Car":                     (    7.946306,   -52.982222,   3.47),  \
  "Ome Cnc":                     (    8.015528,    25.392778,   5.83),  \
  "Chi Gem":                     (    8.058639,    27.794167,   4.94),  \
  "Naos":                        (    8.059750,   -40.003333,   2.25),  \
  "Mu Cnc":                      (    8.105111,    22.635556,   5.99),  \
  "Rho Pup":                     (    8.125722,   -24.304167,   2.81),  \
  "Zet Mon":                     (    8.143222,    -2.983889,   4.34),  \
  "Psi Cnc":                     (    8.174222,    25.507222,   5.73),  \
  "Suhail al Muhlif":            (    8.158139,   -47.345833,   4.27),  \
  "Tegmine":                     (    8.203528,    17.647778,   5.63),  \
  "Eps Vol":                     (    8.132167,   -68.617222,   4.35),  \
  "Altarf":                      (    8.275250,     9.185556,   3.52),  \
  "Chi Cnc":                     (    8.334417,    27.217778,   5.14),  \
  "Lam Cnc":                     (    8.342250,    24.022222,   5.98),  \
  "Kap Vol":                     (    8.330278,   -71.515000,   5.37),  \
  "Phi Cnc":                     (    8.441028,    27.893611,   5.57),  \
  "Avior":                       (    8.375222,   -59.509722,   1.86),  \
  "Alp Cha":                     (    8.308778,   -76.919722,   4.07),  \
  "Muscida":                     (    8.504417,    60.718056,   3.36),  \
  "Eta Vol":                     (    8.367889,   -73.400000,   5.29),  \
  "The Cha":                     (    8.344028,   -77.484444,   4.35),  \
  "Bet Vol":                     (    8.428944,   -66.136944,   3.77),  \
  "Ups Cnc":                     (    8.525139,    24.081111,   5.75),  \
  "The Cnc":                     (    8.526583,    18.094444,   5.35),  \
  "Eta Cnc":                     (    8.545139,    20.441111,   5.33),  \
  "Pi UMa":                      (    8.653250,    65.020833,   5.64),  \
  "Del Hya":                     (    8.627611,     5.703611,   4.16),  \
  "Al Minliar al Shuja":         (    8.645944,     3.341389,   4.44),  \
  "Eta Pyx":                     (    8.631167,   -26.255000,   5.27),  \
  "Eps Cnc":                     (    8.674167,    19.545000,   6.30),  \
  "Zet Pyx":                     (    8.661806,   -29.561111,   4.89),  \
  "Bet Pyx":                     (    8.668389,   -35.308333,   3.97),  \
  "Asellus Borealis":            (    8.721417,    21.468611,   4.66),  \
  "Eta Hya":                     (    8.720417,     3.398611,   4.30),  \
  "The Vol":                     (    8.651444,   -70.386944,   5.20),  \
  "Asellus Australis":           (    8.744750,    18.154167,   3.94),  \
  "Alp Pyx":                     (    8.726528,   -33.186389,   3.68),  \
  "Iot Cnc":                     (    8.777778,    28.765278,   6.57),  \
  "Eps Hya":                     (    8.779611,     6.418889,   3.38),  \
  "Del Vel":                     (    8.745056,   -54.708333,   1.96),  \
  "Rho Hya":                     (    8.807222,     5.837778,   4.36),  \
  "Eta Cha":                     (    8.688750,   -78.963333,   5.47),  \
  "Gam Pyx":                     (    8.842194,   -27.710000,   4.01),  \
  "Sig Cnc":                     (    8.876278,    32.474167,   5.66),  \
  "Rho Cnc":                     (    8.876611,    28.330833,   5.95),  \
  "Zet Hya":                     (    8.923222,     5.945556,   3.11),  \
  "Del Pyx":                     (    8.925417,   -27.681944,   4.89),  \
  "Omi Cnc":                     (    8.954139,    15.322778,   5.20),  \
  "Talitha":                     (    8.986778,    48.041667,   3.14),  \
  "Acubens":                     (    8.974778,    11.857778,   4.25),  \
  "Rho UMa":                     (    9.042417,    67.629722,   4.76),  \
  "Kap UMa":                     (    9.060417,    47.156667,   3.60),  \
  "Nu Cnc":                      (    9.045639,    24.452778,   5.45),  \
  "Sig UMa":                     (    9.139889,    66.873333,   5.14),  \
  "Ome Hya":                     (    9.099556,     5.092222,   4.97),  \
  "Alp Vol":                     (    9.040778,   -66.396111,   4.00),  \
  "Tau Cnc":                     (    9.133361,    29.654167,   5.43),  \
  "Kap Cnc":                     (    9.129111,    10.668056,   5.24),  \
  "Tau UMa":                     (    9.181972,    63.513611,   4.67),  \
  "Xi Cnc":                      (    9.155972,    22.045556,   5.14),  \
  "Kap Pyx":                     (    9.134139,   -25.858333,   4.58),  \
  "Alsuhail":                    (    9.133278,   -43.432500,   2.21),  \
  "Eps Pyx":                     (    9.165667,   -30.365278,   5.59),  \
  "Pi Cnc":                      (    9.204889,    14.996111,   6.51),  \
  "The Hya":                     (    9.239417,     2.314167,   3.88),  \
  "Zet Oct":                     (    8.944750,   -85.663056,   5.42),  \
  "Miaplacidus":                 (    9.220000,   -69.717222,   1.68),  \
  "Turais":                      (    9.284833,   -59.275278,   2.25),  \
  "Alp Lyn":                     (    9.350917,    34.392500,   3.13),  \
  "The Pyx":                     (    9.358222,   -25.965556,   4.72),  \
  "Al Minliar al Asad":          (    9.410917,    26.182222,   4.46),  \
  "Lam Pyx":                     (    9.386750,   -28.833889,   4.69),  \
  "Kap Vel":                     (    9.368556,   -55.010833,   2.50),  \
  "Alphard":                     (    9.459778,    -8.658611,   1.98),  \
  "Ome Leo":                     (    9.474306,     9.056667,   5.41),  \
  "Tau Hya":                     (    9.485806,    -2.768889,   4.60),  \
  "Eps Ant":                     (    9.487417,   -35.951389,   4.51),  \
  "Alterf":                      (    9.528667,    22.968056,   4.31),  \
  "The UMa":                     (    9.547611,    51.677222,   3.17),  \
  "Zet Ant":                     (    9.512611,   -31.891389,   7.00),  \
  "Xi Leo":                      (    9.532417,    11.299722,   4.97),  \
  "Psi Vel":                     (    9.511667,   -40.466667,   3.60),  \
  "Iot Cha":                     (    9.402528,   -80.786944,   5.36),  \
  "Iot Hya":                     (    9.664278,    -1.142778,   3.91),  \
  "Kap Hya":                     (    9.671778,   -14.332222,   5.06),  \
  "Subra":                       (    9.685833,     9.892222,   3.52),  \
  "Zet Cha":                     (    9.564778,   -80.941389,   5.11),  \
  "Psi Leo":                     (    9.728861,    14.021667,   5.35),  \
  "The Ant":                     (    9.736694,   -27.769444,   4.79),  \
  "Ras Elased Australis":        (    9.764194,    23.774167,   2.98),  \
  "Ups UMa":                     (    9.849833,    59.038611,   3.80),  \
  "Ups Car":                     (    9.785028,   -65.071944,   3.01),  \
  "Phi UMa":                     (    9.868444,    54.064444,   4.59),  \
  "Nu Cha":                      (    9.772389,   -76.776111,   5.45),  \
  "Ups Hya":                     (    9.857972,   -14.846667,   4.12),  \
  "Mu Leo":                      (    9.879389,    26.006944,   3.88),  \
  "Gam Sex":                     (    9.875111,    -8.105000,   5.05),  \
  "Nu Leo":                      (    9.970389,    12.444722,   5.26),  \
  "Phi Vel":                     (    9.947722,   -54.567778,   3.54),  \
  "Eta Ant":                     (    9.981194,   -35.891111,   5.23),  \
  "Pi Leo":                      (   10.003556,     8.044167,   4.70),  \
  "Eta Leo":                     (   10.122222,    16.762778,   3.52),  \
  "Alp Sex":                     (   10.132306,    -0.371667,   4.49),  \
  "Regulus":                     (   10.139528,    11.967222,   1.35),  \
  "Mu Cha":                      (   10.012139,   -82.214722,   5.52),  \
  "Lam Hya":                     (   10.176472,   -12.354167,   3.61),  \
  "Adhafera":                    (   10.278167,    23.417222,   3.44),  \
  "Tania Borealis":              (   10.284944,    42.914444,   3.45),  \
  "Ome Car":                     (   10.228944,   -70.038056,   3.32),  \
  "Eps Sex":                     (   10.293833,    -8.068889,   5.24),  \
  "Algeiba":                     (   10.332861,    19.841667,   2.61),  \
  "Mu UMa":                      (   10.372139,    41.499444,   3.05),  \
  "Mu Hya":                      (   10.434833,   -16.836389,   3.81),  \
  "Bet LMi":                     (   10.464722,    36.707222,   4.21),  \
  "Alp Ant":                     (   10.452528,   -31.067778,   4.25),  \
  "Del Sex":                     (   10.491306,    -2.739167,   5.21),  \
  "Del Ant":                     (   10.493167,   -30.607222,   5.56),  \
  "Bet Sex":                     (   10.504861,    -0.636944,   5.09),  \
  "Rho Leo":                     (   10.546861,     9.306667,   3.85),  \
  "Phi Hya":                     (   10.604639,   -16.344444,   6.03),  \
  "Gam Cha":                     (   10.591139,   -78.607778,   4.11),  \
  "The Car":                     (   10.715944,   -64.394444,   2.76),  \
  "Eta Car":                     (   10.751000,   -59.684167,   6.21),  \
  "Mu Vel":                      (   10.779500,   -49.420000,   2.69),  \
  "Del Cha":                     (   10.754361,   -80.469722,   5.47),  \
  "Nu Hya":                      (   10.827083,   -16.193611,   3.11),  \
  "Ome UMa":                     (   10.899639,    43.190000,   4.71),  \
  "Iot Ant":                     (   10.945306,   -37.137778,   4.60),  \
  "Alkes":                       (   10.996250,   -18.298889,   4.08),  \
  "Merak":                       (   11.030694,    56.382500,   2.37),  \
  "Dubhe":                       (   11.062139,    61.750833,   1.79),  \
  "Chi Leo":                     (   11.083611,     7.336111,   4.63),  \
  "Eta Oct":                     (   10.987167,   -84.593889,   6.19),  \
  "Chi Hya":                     (   11.088861,   -27.293611,   4.94),  \
  "Psi UMa":                     (   11.161056,    44.498611,   3.01),  \
  "Bet Crt":                     (   11.194306,   -22.825833,   4.48),  \
  "Psi Crt":                     (   11.208444,   -18.500000,   6.13),  \
  "Zosma":                       (   11.235139,    20.523611,   2.56),  \
  "Chort":                       (   11.237333,    15.429444,   3.34),  \
  "Phi Leo":                     (   11.277694,    -3.651667,   4.47),  \
  "Xi UMa":                      (   11.303028,    31.529167,   4.87),  \
  "Nu UMa":                      (   11.307972,    33.094167,   3.48),  \
  "Del Crt":                     (   11.322361,   -14.778611,   3.56),  \
  "Sig Leo":                     (   11.352278,     6.029444,   4.05),  \
  "Pi Cen":                      (   11.350111,   -54.491111,   3.89),  \
  "Lam Crt":                     (   11.389417,   -18.780000,   5.09),  \
  "Iot Leo":                     (   11.398750,    10.529167,   3.94),  \
  "Eps Crt":                     (   11.410167,   -10.859444,   4.83),  \
  "Gam Crt":                     (   11.414694,   -17.683889,   4.08),  \
  "Kap Crt":                     (   11.452639,   -12.356667,   5.94),  \
  "Tau Leo":                     (   11.465611,     2.856111,   4.95),  \
  "Lam Dra":                     (   11.523389,    69.331111,   3.84),  \
  "Omi Cen":                     (   11.529472,   -59.442222,   5.13),  \
  "Xi Hya":                      (   11.550028,   -31.857778,   3.54),  \
  "Lam Cen":                     (   11.596333,   -63.019722,   3.13),  \
  "The Crt":                     (   11.611361,    -9.802222,   4.70),  \
  "Ups Leo":                     (   11.615806,    -0.823889,   4.30),  \
  "Pi Cha":                      (   11.621000,   -75.896667,   5.65),  \
  "Ome Vir":                     (   11.641000,     8.134167,   5.36),  \
  "Iot Crt":                     (   11.644472,   -13.201944,   5.48),  \
  "Omi Hya":                     (   11.670222,   -34.744722,   4.70),  \
  "Zet Crt":                     (   11.746056,   -18.350833,   4.73),  \
  "Xi Vir":                      (   11.754750,     8.258333,   4.85),  \
  "Nu Vir":                      (   11.764333,     6.529444,   4.03),  \
  "Chi UMa":                     (   11.767500,    47.779444,   3.71),  \
  "Lam Mus":                     (   11.760111,   -66.728611,   3.64),  \
  "Mu Mus":                      (   11.803972,   -66.814722,   4.72),  \
  "Denebola":                    (   11.817667,    14.571944,   2.14),  \
  "Zavijah":                     (   11.844917,     1.764722,   3.61),  \
  "Bet Hya":                     (   11.881833,   -33.908056,   4.28),  \
  "Phad":                        (   11.897167,    53.694722,   2.44),  \
  "Eta Crt":                     (   11.933583,   -17.150833,   5.18),  \
  "Eps Cha":                     (   11.993694,   -78.221944,   4.91),  \
  "Pi Vir":                      (   12.014556,     6.614167,   4.66),  \
  "The Cru":                     (   12.050417,   -63.312778,   4.33),  \
  "Kap Cha":                     (   12.079583,   -76.519167,   5.04),  \
  "Omi Vir":                     (   12.086806,     8.733056,   4.12),  \
  "Eta Cru":                     (   12.114694,   -64.613611,   4.15),  \
  "Del Cen":                     (   12.139306,   -50.722500,   2.60),  \
  "Alchiba":                     (   12.140222,   -24.728889,   4.02),  \
  "Minkar":                      (   12.168750,   -22.619722,   3.00),  \
  "Rho Cen":                     (   12.194194,   -52.368611,   3.96),  \
  "Del Cru":                     (   12.252417,   -58.748889,   2.80),  \
  "Megrez":                      (   12.257111,    57.032500,   3.31),  \
  "Gienah Ghurab":               (   12.263444,   -17.541944,   2.59),  \
  "Eps Mus":                     (   12.292806,   -67.960833,   4.11),  \
  "Bet Cha":                     (   12.305750,   -79.312222,   4.26),  \
  "Zet Cru":                     (   12.307250,   -64.003056,   4.04),  \
  "Eta Vir":                     (   12.331778,    -0.666944,   3.89),  \
  "Zet Crv":                     (   12.342694,   -22.215833,   5.21),  \
  "Eps Cru":                     (   12.356000,   -60.401111,   3.59),  \
  "Zet Mus":                     (   12.368694,   -67.521944,   5.15),  \
  "Acrux":                       (   12.443306,   -63.099167,   1.33),  \
  "Gam Com":                     (   12.448972,    28.268333,   4.36),  \
  "Sig Cen":                     (   12.467333,   -50.230556,   3.91),  \
  "Algorab":                     (   12.497750,   -16.515556,   2.95),  \
  "Gacrux":                      (   12.519417,   -57.113333,   1.63),  \
  "Gam Mus":                     (   12.541111,   -72.133056,   3.87),  \
  "Eta Crv":                     (   12.534500,   -16.196111,   4.31),  \
  "Bet CVn":                     (   12.562361,    41.357500,   4.26),  \
  "Bet Crv":                     (   12.573111,   -23.396667,   2.65),  \
  "Kap Dra":                     (   12.558056,    69.788333,   3.87),  \
  "Alp Mus":                     (   12.619722,   -69.135556,   2.69),  \
  "Tau Cen":                     (   12.628389,   -48.541111,   3.86),  \
  "Chi Vir":                     (   12.654111,    -7.995556,   4.66),  \
  "Gam Cen":                     (   12.691944,   -48.959722,   2.17),  \
  "Porrima":                     (   12.694333,    -1.449444,   3.65),  \
  "Rho Vir":                     (   12.698083,    10.235556,   4.88),  \
  "Iot Cru":                     (   12.760528,   -60.981111,   4.69),  \
  "Bet Mus":                     (   12.771361,   -68.108056,   3.05),  \
  "Becrux":                      (   12.795333,   -59.688611,   1.25),  \
  "Iot Oct":                     (   12.916278,   -85.123333,   5.46),  \
  "Kap Cru":                     (   12.896972,   -60.376944,   5.90),  \
  "Lam Cru":                     (   12.910889,   -59.146667,   4.62),  \
  "Mu Cru":                      (   12.909889,   -57.177778,   4.03),  \
  "Psi Vir":                     (   12.905889,    -9.538889,   4.79),  \
  "Aliioth":                     (   12.900472,    55.959722,   1.77),  \
  "Auva":                        (   12.926722,     3.397500,   3.38),  \
  "Cor Caroli":                  (   12.933444,    38.314722,   5.60),  \
  "Del Mus":                     (   13.037833,   -71.548889,   3.62),  \
  "Vindemiatrix":                (   13.036278,    10.959167,   2.83),  \
  "Xi Cen":                      (   13.059222,   -49.527222,   4.85),  \
  "The Mus":                     (   13.135278,   -65.306389,   5.51),  \
  "Psi Hya":                     (   13.150917,   -23.118056,   4.95),  \
  "The Vir":                     (   13.165833,    -5.538889,   4.38),  \
  "Diadem":                      (   13.166472,    17.529444,   5.22),  \
  "Bet Com":                     (   13.197889,    27.878056,   4.26),  \
  "Eta Mus":                     (   13.254139,   -67.894444,   4.80),  \
  "Sig Vir":                     (   13.293417,     5.469722,   4.80),  \
  "Gam Hya":                     (   13.315361,   -23.171667,   3.00),  \
  "Iot Cen":                     (   13.343278,   -36.712222,   2.75),  \
  "Iot Mus":                     (   13.418639,   -74.887778,   5.05),  \
  "Mizar":                       (   13.398750,    54.925278,   2.27),  \
  "Spica":                       (   13.419889,   -11.161389,   0.98),  \
  "Kap Oct":                     (   13.682083,   -85.786111,   5.58),  \
  "Heze":                        (   13.578222,    -0.595833,   3.37),  \
  "Eps Cen":                     (   13.664778,   -53.466389,   2.30),  \
  "Tau Boo":                     (   13.787694,    17.456667,   4.50),  \
  "Nu Cen":                      (   13.825083,   -41.687778,   3.41),  \
  "Alkaid":                      (   13.792333,    49.313333,   1.86),  \
  "Mu Cen":                      (   13.826944,   -42.473889,   3.04),  \
  "Ups Boo":                     (   13.824611,    15.797778,   4.07),  \
  "Zet Cen":                     (   13.925667,   -47.288333,   2.55),  \
  "Mufrid":                      (   13.911417,    18.397778,   2.68),  \
  "Phi Cen":                     (   13.971194,   -42.100833,   3.83),  \
  "Ups Cen":                     (   13.978000,   -44.803611,   3.87),  \
  "The Aps":                     (   14.088833,   -76.796667,   5.50),  \
  "Tau Vir":                     (   14.027444,     1.544444,   4.26),  \
  "Hadar":                       (   14.063722,   -60.373056,   0.61),  \
  "Chi Cen":                     (   14.100778,   -41.179722,   4.36),  \
  "Pi Hya":                      (   14.106194,   -26.682500,   3.27),  \
  "Menkent":                     (   14.111389,   -36.370000,   2.06),  \
  "Thuban":                      (   14.073139,    64.375833,   3.65),  \
  "Eta Aps":                     (   14.303833,   -81.007778,   4.91),  \
  "Kap Vir":                     (   14.214944,   -10.273611,   4.19),  \
  "Asellus Tertius":             (   14.224361,    51.787778,   6.69),  \
  "Eps Aps":                     (   14.372972,   -80.108889,   5.06),  \
  "Syrma":                       (   14.266917,    -6.000556,   4.08),  \
  "Del Oct":                     (   14.448583,   -83.667778,   4.32),  \
  "Arcturus":                    (   14.261028,    19.182500,  -0.04),  \
  "Asellus Secondus":            (   14.269417,    51.367222,   4.75),  \
  "Lam Boo":                     (   14.273056,    46.088333,   4.18),  \
  "Iot Lup":                     (   14.323389,   -46.057778,   3.55),  \
  "Lam Vir":                     (   14.318500,   -13.371111,   4.52),  \
  "Ups Vir":                     (   14.325694,    -2.265556,   5.14),  \
  "Psi Cen":                     (   14.342611,   -37.885278,   4.05),  \
  "Tau Lup":                     (   14.435611,   -45.221389,   4.56),  \
  "Asellus Primus":              (   14.419944,    51.850833,   4.05),  \
  "Phi Vir":                     (   14.470028,    -2.228056,   4.81),  \
  "Sig Lup":                     (   14.543583,   -50.456944,   4.42),  \
  "Rho Boo":                     (   14.530500,    30.371389,   3.58),  \
  "Seginus":                     (   14.534639,    38.308333,   3.03),  \
  "Eta Cen":                     (   14.591778,   -42.157778,   2.31),  \
  "Sig Boo":                     (   14.578000,    29.745000,   4.46),  \
  "Rho Lup":                     (   14.631444,   -49.425833,   4.05),  \
  "Rigil Kentaurus":             (   14.659972,   -60.835278,  -0.01),  \
  "Alp Cir":                     (   14.708444,   -64.975278,   3.19),  \
  "Alp Lup":                     (   14.698833,   -47.388333,   2.30),  \
  "Alp Aps":                     (   14.797667,   -79.044722,   3.83),  \
  "Pi Boo":                      (   14.678778,    16.418333,   4.94),  \
  "Zet Boo":                     (   14.685806,    13.728333,   4.83),  \
  "Mu Vir":                      (   14.717667,    -5.658333,   3.88),  \
  "Omi Boo":                     (   14.754028,    16.964444,   4.60),  \
  "Izar":                        (   14.749778,    27.075000,   5.12),  \
  "Mu Lib":                      (   14.821972,   -14.148889,   5.31),  \
  "Pi Oct":                      (   15.030778,   -83.227778,   5.65),  \
  "Omi Lup":                     (   14.860667,   -43.575556,   4.32),  \
  "Zuben Elgenubi":              (   14.844778,   -15.997222,   5.15),  \
  "Zet Cir":                     (   14.911778,   -65.991389,   6.09),  \
  "Xi Boo":                      (   14.856472,    19.101111,   4.55),  \
  "The Cir":                     (   14.945556,   -62.780833,   5.11),  \
  "Xi Lib":                      (   14.906361,   -11.898333,   5.80),  \
  "Ome Oct":                     (   15.185639,   -84.787500,   5.91),  \
  "Kocab":                       (   14.845083,    74.155556,   2.08),  \
  "Bet Lup":                     (   14.975528,   -43.133889,   2.68),  \
  "Kap Cen":                     (   14.986028,   -42.104167,   3.13),  \
  "Zuben Elakribi":              (   15.016222,    -8.518889,   4.92),  \
  "Eta Cir":                     (   15.080056,   -64.031667,   5.17),  \
  "Ome Boo":                     (   15.035139,    25.008056,   4.81),  \
  "Nekkar":                      (   15.032444,    40.390556,   3.50),  \
  "Brachium":                    (   15.067833,   -25.281944,   3.29),  \
  "Pi Lup":                      (   15.085333,   -47.051111,   4.72),  \
  "Psi Boo":                     (   15.074083,    26.947500,   4.54),  \
  "Nu Lib":                      (   15.110444,   -16.256944,   5.20),  \
  "Lam Lup":                     (   15.147389,   -45.279722,   4.05),  \
  "Kap Lup":                     (   15.198917,   -48.737778,   3.87),  \
  "Zet Lup":                     (   15.204750,   -52.099167,   3.41),  \
  "Iot Lib":                     (   15.203694,   -19.791667,   4.54),  \
  "Del Cir":                     (   15.282417,   -60.957500,   5.09),  \
  "Eps Cir":                     (   15.294139,   -63.610556,   4.86),  \
  "Bet Cir":                     (   15.291889,   -58.801111,   4.07),  \
  "Gam TrA":                     (   15.315167,   -68.679444,   2.89),  \
  "Chi Boo":                     (   15.241444,    29.164167,   5.26),  \
  "Del Boo":                     (   15.258389,    33.314722,   3.47),  \
  "Mu Lup":                      (   15.308889,   -47.875000,   4.27),  \
  "Zuben Elschemali":            (   15.283444,    -9.383056,   2.61),  \
  "Del Lup":                     (   15.356194,   -40.647500,   3.22),  \
  "Nu Lup":                      (   15.368972,   -47.927778,   5.00),  \
  "Omi Lib":                     (   15.350389,   -15.548333,   6.30),  \
  "Gam Cir":                     (   15.389639,   -59.320833,   4.51),  \
  "Phi Lup":                     (   15.363444,   -36.261389,   3.56),  \
  "Eps Lup":                     (   15.378028,   -44.689444,   3.37),  \
  "Omi CrB":                     (   15.335694,    29.616111,   5.51),  \
  "Ups Lup":                     (   15.412472,   -39.710278,   5.37),  \
  "Eps Lib":                     (   15.403306,   -10.322222,   4.94),  \
  "Eta CrB":                     (   15.386750,    30.287778,   5.58),  \
  "Rho Oct":                     (   15.721333,   -84.465278,   5.57),  \
  "Kap Aps":                     (   15.525222,   -73.389444,   5.49),  \
  "Mu Boo":                      (   15.408167,    37.377222,   4.31),  \
  "Pherkad":                     (   15.345472,    71.833889,   3.05),  \
  "Tau Ser":                     (   15.429833,    15.428056,   5.17),  \
  "Zet Lib":                     (   15.470944,   -16.716389,   5.64),  \
  "Ed Asich":                    (   15.415500,    58.966111,   3.29),  \
  "Nusakan":                     (   15.463806,    29.105833,   3.68),  \
  "Nu Boo":                      (   15.515500,    40.833056,   5.02),  \
  "Eps TrA":                     (   15.612000,   -66.316944,   4.11),  \
  "Gam Lup":                     (   15.585694,   -41.166944,   2.78),  \
  "The CrB":                     (   15.548833,    31.359167,   4.14),  \
  "Zuben Elakrab":               (   15.592111,   -14.789444,   3.91),  \
  "Del Ser":                     (   15.580028,    10.537500,   3.80),  \
  "Alphekka":                    (   15.578139,    26.714722,   2.23),  \
  "Ups Lib":                     (   15.617083,   -28.135000,   3.58),  \
  "Ome Lup":                     (   15.634222,   -42.567500,   4.33),  \
  "Mu CrB":                      (   15.587500,    39.010000,   5.11),  \
  "Tau Lib":                     (   15.644278,   -29.777778,   3.66),  \
  "Psi Lup":                     (   15.662778,   -34.411944,   4.67),  \
  "Phi Boo":                     (   15.630444,    40.353333,   5.24),  \
  "The UMi":                     (   15.523583,    77.349444,   4.96),  \
  "Zet CrB":                     (   15.656167,    36.636667,   6.00),  \
  "Kap Lib":                     (   15.699111,   -19.678889,   4.74),  \
  "Iot Ser":                     (   15.692528,    19.670278,   4.52),  \
  "Chi Ser":                     (   15.696500,    12.847500,   5.33),  \
  "Eta Lib":                     (   15.734556,   -15.672778,   5.41),  \
  "Gam CrB":                     (   15.712389,    26.295556,   3.84),  \
  "Psi Ser":                     (   15.733833,     2.515000,   5.88),  \
  "Unukalha":                    (   15.737806,     6.425556,   2.65),  \
  "Pi CrB":                      (   15.733139,    32.515833,   5.56),  \
  "Bet Ser":                     (   15.769806,    15.421944,   3.67),  \
  "Lam Ser":                     (   15.774056,     7.353056,   4.43),  \
  "Ups Ser":                     (   15.788139,    14.115278,   5.71),  \
  "Kap Ser":                     (   15.812333,    18.141667,   4.09),  \
  "Mu Ser":                      (   15.827000,    -3.430278,   3.53),  \
  "Chi Lup":                     (   15.849306,   -33.627222,   3.95),  \
  "Ome Ser":                     (   15.838194,     2.196389,   5.23),  \
  "Del CrB":                     (   15.826583,    26.068333,   4.63),  \
  "Kap TrA":                     (   15.924889,   -68.603056,   5.09),  \
  "Eps Ser":                     (   15.846944,     4.477778,   3.71),  \
  "Bet TrA":                     (   15.919028,   -63.430556,   2.85),  \
  "Rho Ser":                     (   15.854417,    20.977778,   4.76),  \
  "Kap CrB":                     (   15.853861,    35.657500,   4.82),  \
  "Lam Lib":                     (   15.888917,   -20.167222,   5.03),  \
  "Zet UMi":                     (   15.734306,    77.794444,   4.32),  \
  "The Lib":                     (   15.897083,   -16.729444,   4.15),  \
  "Chi Her":                     (   15.877917,    42.451667,   4.62),  \
  "Xi Lup":                      (   15.948194,   -33.966389,   5.12),  \
  "Rho Sco":                     (   15.948083,   -29.214167,   3.88),  \
  "Gam Ser":                     (   15.940889,    15.661667,   3.85),  \
  "Lam CrB":                     (   15.929889,    37.946944,   5.45),  \
  "Phi Ser":                     (   15.954056,    14.414444,   5.54),  \
  "Pi Sco":                      (   15.980861,   -26.114167,   2.89),  \
  "Eps CrB":                     (   15.959806,    26.877778,   4.15),  \
  "Eta Lup":                     (   16.002028,   -38.396944,   3.41),  \
  "Dschubba":                    (   16.005556,   -22.621667,   2.32),  \
  "Iot Nor":                     (   16.058861,   -57.775278,   4.63),  \
  "Eta Nor":                     (   16.053583,   -49.229722,   4.65),  \
  "Rho CrB":                     (   16.017417,    33.303611,   5.41),  \
  "Iot CrB":                     (   16.024056,    29.851111,   4.99),  \
  "Pi Ser":                      (   16.038250,    22.804444,   4.83),  \
  "Xi Sco":                      (   16.072806,   -11.373056,   5.07),  \
  "Del Nor":                     (   16.108167,   -45.173333,   4.72),  \
  "Ups Her":                     (   16.046639,    46.036667,   4.76),  \
  "Graffias":                    (   16.090611,   -19.805556,   2.62),  \
  "The Dra":                     (   16.031472,    58.565278,   4.01),  \
  "The Lup":                     (   16.109861,   -36.802222,   4.23),  \
  "Ome Sco":                     (   16.113444,   -20.669167,   3.96),  \
  "Mirfak":                      (   16.134583,    17.046944,   5.00),  \
  "Tau CrB":                     (   16.149528,    36.490833,   4.76),  \
  "Zet Nor":                     (   16.222944,   -55.540833,   5.81),  \
  "Del Aps":                     (   16.339111,   -78.695833,   4.68),  \
  "Phi Her":                     (   16.146167,    44.935000,   4.26),  \
  "Kap Nor":                     (   16.224639,   -54.630556,   4.94),  \
  "Nu Sco":                      (   16.199611,   -19.449722,   6.30),  \
  "Del TrA":                     (   16.257306,   -63.685556,   3.85),  \
  "Psi Sco":                     (   16.200000,   -10.064167,   4.94),  \
  "The Nor":                     (   16.254250,   -47.372222,   5.14),  \
  "Chi Sco":                     (   16.230806,   -11.837500,   5.22),  \
  "Yed Prior":                   (   16.239083,    -3.694444,   2.74),  \
  "Gam Nor":                     (   16.283583,   -50.068333,   4.99),  \
  "Sig CrB":                     (   16.244667,    33.858611,   5.64),  \
  "Lam Nor":                     (   16.321583,   -42.673889,   5.45),  \
  "Ups CrB":                     (   16.279111,    29.150278,   5.78),  \
  "Yed Posterior":               (   16.305361,    -4.692500,   3.24),  \
  "Omi Sco":                     (   16.343944,   -24.169444,   4.55),  \
  "Alniyat":                     (   16.353139,   -25.592778,   2.89),  \
  "Tau Her":                     (   16.329000,    46.313333,   3.89),  \
  "Sig Ser":                     (   16.367889,     1.029167,   4.82),  \
  "Gam Her":                     (   16.365333,    19.153056,   3.75),  \
  "Zet TrA":                     (   16.474472,   -70.084444,   4.91),  \
  "Gam Aps":                     (   16.557500,   -78.897222,   3.89),  \
  "Xi CrB":                      (   16.368278,    30.891944,   4.85),  \
  "Psi Oph":                     (   16.401722,   -20.037500,   4.50),  \
  "Nu CrB":                      (   16.372611,    33.799167,   5.20),  \
  "Iot TrA":                     (   16.465917,   -64.058056,   5.27),  \
  "Rho Oph":                     (   16.426444,   -23.447222,   5.02),  \
  "Eps Nor":                     (   16.453083,   -47.555000,   4.47),  \
  "Eta UMi":                     (   16.291750,    75.755278,   4.95),  \
  "Cujam":                       (   16.423611,    14.033333,   4.57),  \
  "Chi Oph":                     (   16.450389,   -18.456389,   4.42),  \
  "Ups Oph":                     (   16.463361,    -8.371667,   4.63),  \
  "Eta Dra":                     (   16.399861,    61.514167,   2.74),  \
  "Antares":                     (   16.490111,   -26.431944,   0.96),  \
  "Phi Oph":                     (   16.518972,   -16.612778,   4.28),  \
  "Kornephoros":                 (   16.503667,    21.489722,   2.77),  \
  "Marfik":                      (   16.515222,     1.983889,   3.82),  \
  "The TrA":                     (   16.595778,   -65.495278,   5.52),  \
  "Ome Oph":                     (   16.535611,   -21.466389,   4.45),  \
  "Mu Nor":                      (   16.568056,   -44.045278,   4.94),  \
  "Bet Aps":                     (   16.717944,   -77.517500,   4.24),  \
  "Tau Sco":                     (   16.598056,   -28.216111,   2.82),  \
  "Sig Her":                     (   16.568389,    42.436944,   4.20),  \
  "Eta TrA":                     (   16.689806,   -68.296111,   5.91),  \
  "Zet Oph":                     (   16.619306,   -10.567222,   2.56),  \
  "Zet Her":                     (   16.688111,    31.603056,   2.81),  \
  "Atria":                       (   16.811083,   -69.027778,   1.92),  \
  "Eta Her":                     (   16.714944,    38.922222,   3.53),  \
  "Eta Ara":                     (   16.829750,   -59.041389,   3.76),  \
  "Eps Sco":                     (   16.836056,   -34.293333,   2.29),  \
  "Mu Sco":                      (   16.864500,   -38.047500,   3.08),  \
  "Zet Sco":                     (   16.899917,   -42.362222,   4.73),  \
  "Iot Oph":                     (   16.900139,    10.165278,   4.38),  \
  "Zet Ara":                     (   16.977000,   -55.990278,   3.13),  \
  "Eps Ara":                     (   16.993083,   -53.160556,   4.06),  \
  "Kap Oph":                     (   16.961139,     9.375000,   3.20),  \
  "Eps UMi":                     (   16.766139,    82.037222,   4.23),  \
  "Eps Her":                     (   17.004833,    30.926389,   3.92),  \
  "Mu Dra":                      (   17.088833,    54.470278,   5.83),  \
  "Sabik":                       (   17.172972,   -15.724722,   2.43),  \
  "Eta Sco":                     (   17.202556,   -43.239167,   3.33),  \
  "Aldhibah":                    (   17.146444,    65.714722,   3.17),  \
  "Rasalgethi":                  (   17.244139,    14.390278,   3.48),  \
  "Sarin":                       (   17.250528,    24.839167,   3.14),  \
  "Iot Aps":                     (   17.368306,   -70.123333,   5.41),  \
  "Zet Aps":                     (   17.366500,   -67.770556,   4.78),  \
  "Pi Her":                      (   17.250778,    36.809167,   3.16),  \
  "Omi Oph":                     (   17.300194,   -24.286944,   5.20),  \
  "Xi Oph":                      (   17.350056,   -21.112778,   4.39),  \
  "Nu Ser":                      (   17.347139,   -12.846944,   4.33),  \
  "Iot Ara":                     (   17.387806,   -47.468333,   5.25),  \
  "The Oph":                     (   17.366833,   -24.999444,   3.27),  \
  "Bet Ara":                     (   17.421667,   -55.530000,   2.85),  \
  "Gam Ara":                     (   17.423222,   -56.377500,   3.34),  \
  "Kap Ara":                     (   17.433333,   -50.633611,   5.23),  \
  "Rho Her":                     (   17.394639,    37.146667,   5.47),  \
  "Sig Oph":                     (   17.441917,     4.140278,   4.34),  \
  "Del Ara":                     (   17.518306,   -60.683889,   3.62),  \
  "Ups Sco":                     (   17.512722,   -37.295833,   2.69),  \
  "Alp Ara":                     (   17.530694,   -49.876111,   2.95),  \
  "Maasym":                      (   17.512306,    26.110556,   4.41),  \
  "Lam Sco":                     (   17.560139,   -37.103889,   1.63),  \
  "Rastaban":                    (   17.507222,    52.301389,   2.79),  \
  "Sig Ara":                     (   17.594333,   -46.505556,   4.59),  \
  "Pi Ara":                      (   17.634889,   -54.500278,   5.25),  \
  "Sargas":                      (   17.622000,   -42.997778,   1.87),  \
  "Nu Dra":                      (   17.536278,    55.184167,   4.88),  \
  "Rasalhague":                  (   17.582250,    12.560000,   2.08),  \
  "Xi Ser":                      (   17.626444,   -15.398611,   3.54),  \
  "Mu Oph":                      (   17.630750,    -8.118889,   4.62),  \
  "Lam Ara":                     (   17.673222,   -49.415556,   4.77),  \
  "Kap Sco":                     (   17.708139,   -39.030000,   2.41),  \
  "Omi Ser":                     (   17.690250,   -12.875278,   4.26),  \
  "Eta Pav":                     (   17.762222,   -64.723889,   3.62),  \
  "Mu Ara":                      (   17.735750,   -51.834167,   5.15),  \
  "Iot Her":                     (   17.657750,    46.006389,   3.80),  \
  "Ome Dra":                     (   17.615861,    68.758056,   4.80),  \
  "Cebalrai":                    (   17.724556,     4.567222,   2.77),  \
  "Iot Sco":                     (   17.793083,   -40.126944,   3.03),  \
  "Mu Her":                      (   17.774306,    27.720556,   3.42),  \
  "Gam Oph":                     (   17.798222,     2.707222,   3.75),  \
  "Dsiban":                      (   17.698972,    72.148889,   4.58),  \
  "Xi Dra":                      (   17.892139,    56.872778,   3.75),  \
  "The Her":                     (   17.937556,    37.250556,   3.86),  \
  "Nu Oph":                      (   17.983778,    -9.773611,   3.34),  \
  "Xi Her":                      (   17.962750,    29.247778,   3.70),  \
  "Gianfar":                     (   17.943444,    51.488889,   2.23),  \
  "Nu Her":                      (   17.975056,    30.189444,   4.41),  \
  "Zet Ser":                     (   18.008056,    -3.690278,   4.62),  \
  "Chi Oct":                     (   18.913028,   -87.605833,   5.28),  \
  "Tau Oph":                     (   18.051389,    -8.180278,   5.94),  \
  "Nash":                        (   18.083694,   -29.580000,   4.69),  \
  "The Ara":                     (   18.110528,   -50.091667,   3.66),  \
  "Pi Pav":                      (   18.143000,   -63.668333,   4.35),  \
  "Iot Pav":                     (   18.173917,   -62.002222,   5.49),  \
  "Omi Her":                     (   18.125722,    28.762500,   3.83),  \
  "Eps Tel":                     (   18.187167,   -45.954444,   4.53),  \
  "Yildun":                      (   17.536917,    86.586389,   4.36),  \
  "Mu Sgr":                      (   18.229389,   -21.058889,   3.86),  \
  "Phi Oct":                     (   18.393361,   -75.044167,   5.47),  \
  "Eta Sgr":                     (   18.293778,   -36.761667,   3.11),  \
  "Xi Pav":                      (   18.387111,   -61.493889,   4.36),  \
  "Kaus Media":                  (   18.349917,   -29.828056,   2.70),  \
  "Eta Ser":                     (   18.355167,    -2.898889,   3.26),  \
  "Kap Lyr":                     (   18.331028,    36.064444,   4.33),  \
  "Kaus Australis":              (   18.402861,   -34.384722,   1.85),  \
  "Zet Sct":                     (   18.394306,    -8.934167,   4.68),  \
  "Alp Tel":                     (   18.449556,   -45.968333,   3.51),  \
  "Mu Lyr":                      (   18.403833,    39.507222,   5.12),  \
  "Zet Tel":                     (   18.480528,   -49.070833,   4.13),  \
  "Kaus Borealis":               (   18.466167,   -25.421667,   2.81),  \
  "Nu Pav":                      (   18.522889,   -62.278333,   4.64),  \
  "Phi Dra":                     (   18.345972,    71.337778,   4.22),  \
  "Chi Dra":                     (   18.350944,    72.732778,   3.57),  \
  "Gam Sct":                     (   18.486639,   -14.565833,   4.70),  \
  "Del Tel":                     (   18.529278,   -45.915000,   4.96),  \
  "The CrA":                     (   18.558389,   -42.312500,   4.64),  \
  "Kap CrA":                     (   18.556472,   -38.720278,   6.32),  \
  "Alp Sct":                     (   18.586778,    -8.244167,   3.85),  \
  "Zet Pav":                     (   18.717250,   -71.428056,   4.01),  \
  "Vega":                        (   18.615639,    38.783611,   0.03),  \
  "Del Sct":                     (   18.704556,    -9.052500,   4.72),  \
  "Lam CrA":                     (   18.729694,   -38.323611,   5.13),  \
  "Eps Sct":                     (   18.725361,    -8.275278,   4.90),  \
  "The Pav":                     (   18.810500,   -65.077778,   5.73),  \
  "Phi Sgr":                     (   18.760944,   -26.990833,   3.17),  \
  "Mu CrA":                      (   18.795722,   -40.406111,   5.24),  \
  "Eps Lyr":                     (   18.739000,    39.670000,   5.06),  \
  "Zet Lyr":                     (   18.746222,    37.605000,   4.36),  \
  "Eta CrA":                     (   18.814028,   -43.680000,   5.49),  \
  "Bet Sct":                     (   18.786250,    -4.747778,   4.22),  \
  "Lam Pav":                     (   18.870278,   -62.187500,   4.22),  \
  "Kap Tel":                     (   18.877667,   -52.107500,   5.17),  \
  "Nu Lyr":                      (   18.829417,    32.812778,   5.91),  \
  "Sheliak":                     (   18.834667,    33.362778,   3.45),  \
  "Kap Pav":                     (   18.949167,   -67.233611,   4.44),  \
  "Nu Sgr":                      (   18.902833,   -22.745000,   4.83),  \
  "Nunki":                       (   18.921083,   -26.296667,   2.02),  \
  "Omi Dra":                     (   18.853361,    59.388333,   4.66),  \
  "Ome Pav":                     (   18.976778,   -60.200556,   5.14),  \
  "Del Lyr":                     (   18.895444,    36.971667,   5.58),  \
  "Lam Tel":                     (   18.974361,   -52.938611,   4.87),  \
  "The Ser":                     (   18.937000,     4.203611,   4.62),  \
  "Xi Sgr":                      (   18.955694,   -20.656389,   5.08),  \
  "Eta Sct":                     (   18.951028,    -5.846111,   4.83),  \
  "Eps CrA":                     (   18.978722,   -37.107500,   4.87),  \
  "Eps Aql":                     (   18.993722,    15.068333,   4.02),  \
  "Sulafat":                     (   18.982389,    32.689444,   3.24),  \
  "Ups Dra":                     (   18.906639,    71.297222,   4.82),  \
  "Zet CrA":                     (   19.051917,   -42.095278,   4.75),  \
  "Lam Lyr":                     (   19.000250,    32.145556,   4.93),  \
  "Ascella":                     (   19.043528,   -29.880278,   2.60),  \
  "Rho Tel":                     (   19.105528,   -52.340833,   5.16),  \
  "Omi Sgr":                     (   19.078056,   -21.741667,   3.77),  \
  "Gam CrA":                     (   19.106972,   -37.063333,   4.93),  \
  "Polaris Australis":           (   21.146167,   -88.956389,   5.47),  \
  "Tau Sgr":                     (   19.115667,   -27.670556,   3.32),  \
  "Deneb el Okab":               (   19.090167,    13.863333,   2.99),  \
  "Lam Aql":                     (   19.104139,    -4.882500,   3.44),  \
  "Del CrA":                     (   19.139139,   -40.496667,   4.59),  \
  "Alfecca Meridiana":           (   19.157861,   -37.904444,   4.11),  \
  "Bet CrA":                     (   19.167139,   -39.340833,   4.11),  \
  "Iot Lyr":                     (   19.121694,    36.100278,   5.28),  \
  "Pi Sgr":                      (   19.162722,   -21.023611,   2.89),  \
  "Tau Pav":                     (   19.274583,   -69.190556,   6.27),  \
  "Psi Sgr":                     (   19.259000,   -25.256667,   4.85),  \
  "Aladfar":                     (   19.229306,    39.146111,   4.39),  \
  "Nodus Secundus":              (   19.209250,    67.661667,   3.07),  \
  "The Lyr":                     (   19.272806,    38.133611,   4.36),  \
  "Ome Aql":                     (   19.296944,    11.595278,   5.28),  \
  "Kap Cyg":                     (   19.285056,    53.368611,   3.77),  \
  "Eta Tel":                     (   19.380861,   -54.423611,   5.05),  \
  "Arkab":                       (   19.377306,   -44.458889,   4.01),  \
  "Rho Sgr":                     (   19.361222,   -17.847222,   3.93),  \
  "Ups Sgr":                     (   19.362111,   -15.955000,   4.61),  \
  "Rukbat":                      (   19.398111,   -40.616111,   3.97),  \
  "Tau Dra":                     (   19.259167,    73.355556,   4.45),  \
  "Chi Sgr":                     (   19.421250,   -24.508611,   5.03),  \
  "Pi Dra":                      (   19.344472,    65.714722,   4.59),  \
  "Del Aql":                     (   19.424972,     3.114722,   3.36),  \
  "Nu Aql":                      (   19.441972,     0.338611,   4.66),  \
  "Mu Tel":                      (   19.509583,   -55.110000,   6.30),  \
  "Lam UMi":                     (   17.282444,    89.037778,   6.38),  \
  "Anser":                       (   19.478417,    24.665000,   4.44),  \
  "Iot Cyg":                     (   19.457194,    52.320556,   5.75),  \
  "Albireo":                     (   19.512028,    27.959722,   3.08),  \
  "Iot Tel":                     (   19.586944,   -48.099167,   4.90),  \
  "Mu Aql":                      (   19.568167,     7.378889,   4.45),  \
  "Kap Aql":                     (   19.614861,    -7.027500,   4.95),  \
  "Iot Aql":                     (   19.612028,    -1.286389,   4.36),  \
  "Alsafi":                      (   19.539333,    69.661111,   4.68),  \
  "Eps Sge":                     (   19.621500,    16.462778,   5.66),  \
  "The Cyg":                     (   19.607361,    50.221111,   4.48),  \
  "Sig Aql":                     (   19.653222,     5.397778,   5.17),  \
  "Phi Cyg":                     (   19.656278,    30.153333,   4.69),  \
  "Sham":                        (   19.668278,    18.013889,   4.37),  \
  "Bet Sge":                     (   19.684139,    17.476111,   4.37),  \
  "Chi Aql":                     (   19.709444,    11.826667,   5.27),  \
  "Nu Tel":                      (   19.800333,   -56.362500,   5.35),  \
  "Psi Aql":                     (   19.742806,    13.302778,   6.26),  \
  "Ups Aql":                     (   19.761083,     7.613333,   5.91),  \
  "Tarazed":                     (   19.771000,    10.613333,   2.72),  \
  "Del Cyg":                     (   19.749583,    45.130833,   2.87),  \
  "Del Sge":                     (   19.789806,    18.534167,   3.82),  \
  "Pi Aql":                      (   19.811694,    11.815833,   5.72),  \
  "Zet Sge":                     (   19.816306,    19.142222,   5.00),  \
  "Altair":                      (   19.846389,     8.868333,   0.77),  \
  "Omi Aql":                     (   19.850444,    10.415556,   5.11),  \
  "Chi Cyg":                     (   19.842750,    32.914167,   4.23),  \
  "Eta Aql":                     (   19.874556,     1.005556,   3.90),  \
  "Iot Sgr":                     (   19.921028,   -41.868333,   4.13),  \
  "Eps Dra":                     (   19.802889,    70.267778,   3.83),  \
  "Eps Pav":                     (   20.009861,   -72.910556,   3.96),  \
  "Xi Aql":                      (   19.904139,     8.461389,   4.71),  \
  "Terebellum":                  (   19.930667,   -26.299444,   4.70),  \
  "Alshain":                     (   19.921889,     6.406667,   3.71),  \
  "Mu Pav":                      (   20.006389,   -66.949444,   5.76),  \
  "Phi Aql":                     (   19.937306,    11.423889,   5.28),  \
  "Eta Cyg":                     (   19.938444,    35.083333,   3.89),  \
  "Psi Cyg":                     (   19.927167,    52.438889,   4.92),  \
  "The Sgr":                     (   19.995611,   -35.276389,   4.37),  \
  "Gam Sge":                     (   19.979278,    19.492222,   3.47),  \
  "Del Pav":                     (   20.145444,   -66.181944,   3.56),  \
  "Tau Aql":                     (   20.068972,     7.278056,   5.52),  \
  "Xi Tel":                      (   20.123111,   -52.880833,   4.94),  \
  "Eta Sge":                     (   20.085972,    19.991111,   5.10),  \
  "Rho Dra":                     (   20.046972,    67.873611,   4.51),  \
  "The Sge":                     (   20.165722,    20.915278,   6.48),  \
  "The Aql":                     (   20.188417,    -0.821389,   3.23),  \
  "Xi Cap":                      (   20.199417,   -12.392500,   6.34),  \
  "Rho Aql":                     (   20.237944,    15.197500,   4.95),  \
  "Alp Cap":                     (   20.294139,   -12.508333,   4.24),  \
  "Kap Cep":                     (   20.148139,    77.711389,   4.39),  \
  "Sig Cap":                     (   20.323222,   -19.118611,   5.28),  \
  "Nu Cap":                      (   20.344389,   -12.759167,   4.76),  \
  "Dabih":                       (   20.350194,   -14.781389,   3.08),  \
  "Kap Sgr":                     (   20.374306,   -42.049722,   5.59),  \
  "Peacock":                     (   20.427472,   -56.735000,   1.94),  \
  "Sadr":                        (   20.370472,    40.256667,   2.20),  \
  "Pi Cap":                      (   20.455333,   -18.211667,   5.25),  \
  "Rho Cap":                     (   20.481000,   -17.813611,   4.78),  \
  "Omi Cap":                     (   20.497917,   -18.586667,   6.74),  \
  "Ruchba":                      (   20.500972,    48.951667,   4.95),  \
  "Nu Mic":                      (   20.565306,   -44.516111,   5.11),  \
  "Phi Pav":                     (   20.593000,   -60.581667,   4.76),  \
  "The Cep":                     (   20.493028,    62.994167,   4.22),  \
  "Deneb Dulfim":                (   20.553556,    11.303333,   4.03),  \
  "Eta Del":                     (   20.565833,    13.027222,   5.38),  \
  "Rho Pav":                     (   20.626472,   -61.530000,   4.88),  \
  "Mu Oct":                      (   20.700806,   -76.180556,   6.00),  \
  "Alp Ind":                     (   20.626111,   -47.291389,   3.11),  \
  "Zet Del":                     (   20.588472,    14.674167,   4.68),  \
  "Ups Pav":                     (   20.699194,   -66.760833,   5.15),  \
  "Rotanev":                     (   20.625833,    14.595278,   3.63),  \
  "Iot Del":                     (   20.630306,    11.377778,   5.43),  \
  "Tau Cap":                     (   20.654556,   -14.954722,   5.22),  \
  "The Del":                     (   20.645528,    13.315000,   5.72),  \
  "Kap Del":                     (   20.652167,    10.086111,   5.05),  \
  "Ups Cap":                     (   20.667500,   -18.138611,   5.10),  \
  "Sualocin":                    (   20.660639,    15.911944,   3.77),  \
  "Bet Pav":                     (   20.749306,   -66.203056,   3.42),  \
  "Eta Ind":                     (   20.733972,   -51.921111,   4.51),  \
  "Deneb":                       (   20.690528,    45.280278,   1.25),  \
  "Del Del":                     (   20.724306,    15.074444,   4.43),  \
  "Sig Pav":                     (   20.821694,   -68.776389,   5.41),  \
  "Psi Cap":                     (   20.768250,   -25.270833,   4.14),  \
  "Iot Mic":                     (   20.808111,   -43.988611,   5.11),  \
  "Gam Del":                     (   20.777417,    16.124444,   5.14),  \
  "Gienah Cygni":                (   20.770194,    33.970278,   2.46),  \
  "Albali":                      (   20.794611,    -9.495833,   3.77),  \
  "Zet Ind":                     (   20.824722,   -46.226944,   4.89),  \
  "Eta Cep":                     (   20.754833,    61.838889,   3.43),  \
  "Lam Cyg":                     (   20.790139,    36.490833,   4.53),  \
  "Alp Mic":                     (   20.832806,   -33.779722,   4.90),  \
  "Iot Ind":                     (   20.858361,   -51.608333,   5.05),  \
  "Bet Mic":                     (   20.866333,   -33.177222,   6.04),  \
  "Ome Cap":                     (   20.863694,   -26.919167,   4.11),  \
  "Bet Ind":                     (   20.913500,   -58.454167,   3.65),  \
  "Mu Aqr":                      (   20.877556,    -8.983333,   4.73),  \
  "Alp Oct":                     (   21.078611,   -77.023889,   5.15),  \
  "Nu Cyg":                      (   20.952889,    41.167222,   3.94),  \
  "Eps Equ":                     (   20.984556,     4.293611,   5.23),  \
  "Gam Mic":                     (   21.021528,   -32.257778,   4.67),  \
  "Zet Mic":                     (   21.049444,   -38.631667,   5.30),  \
  "Mu Ind":                      (   21.087278,   -54.727222,   5.16),  \
  "Eta Cap":                     (   21.073417,   -19.855000,   4.84),  \
  "Eta Mic":                     (   21.107083,   -41.386111,   5.53),  \
  "Del Mic":                     (   21.100333,   -30.125000,   5.68),  \
  "The Cap":                     (   21.099111,   -17.232778,   4.07),  \
  "Xi Cyg":                      (   21.082194,    43.927778,   3.72),  \
  "Chi Cap":                     (   21.142667,   -21.193611,   5.30),  \
  "Omi Pav":                     (   21.222361,   -70.126389,   5.02),  \
  "Nu Aqr":                      (   21.159917,   -11.371667,   4.51),  \
  "Gam Equ":                     (   21.172361,    10.131667,   4.69),  \
  "Zet Cyg":                     (   21.215611,    30.226944,   3.20),  \
  "Del Equ":                     (   21.241361,    10.006944,   4.49),  \
  "Phi Cap":                     (   21.260528,   -20.651667,   5.24),  \
  "Tau Cyg":                     (   21.246528,    38.045556,   3.72),  \
  "Kitalpha":                    (   21.263722,     5.247778,   3.92),  \
  "Eps Mic":                     (   21.298972,   -32.172500,   4.71),  \
  "The Ind":                     (   21.331111,   -53.449722,   4.39),  \
  "Sig Cyg":                     (   21.290278,    39.394722,   4.23),  \
  "Ups Cyg":                     (   21.298639,    34.896944,   4.43),  \
  "The Mic":                     (   21.346000,   -40.809722,   4.82),  \
  "Adleramin":                   (   21.309667,    62.585556,   2.44),  \
  "Iot Cap":                     (   21.370778,   -16.834444,   4.28),  \
  "Bet Equ":                     (   21.381556,     6.811111,   5.16),  \
  "Gam Pav":                     (   21.440722,   -65.366111,   4.22),  \
  "Gam Ind":                     (   21.437611,   -54.660556,   6.12),  \
  "Zet Cap":                     (   21.444444,   -22.411389,   3.74),  \
  "Xi Gru":                      (   21.534972,   -41.179167,   5.29),  \
  "Sadalsuud":                   (   21.525972,    -5.571111,   2.91),  \
  "Alfirk":                      (   21.477667,    70.560833,   3.23),  \
  "Rho Cyg":                     (   21.566361,    45.591944,   4.02),  \
  "Nu Oct":                      (   21.691250,   -77.390000,   3.76),  \
  "Eps Cap":                     (   21.618000,   -19.466111,   4.68),  \
  "Xi Aqr":                      (   21.629194,    -7.854167,   4.69),  \
  "Nashira":                     (   21.668194,   -16.662222,   3.68),  \
  "Lam Oct":                     (   21.848417,   -82.719167,   5.29),  \
  "Kap Cap":                     (   21.710972,   -18.866389,   4.73),  \
  "Pi Cyg":                      (   21.701583,    51.189722,   4.67),  \
  "Iot PsA":                     (   21.749111,   -33.025833,   4.34),  \
  "Enif":                        (   21.736444,     9.875000,   2.39),  \
  "Mu Cyg":                      (   21.735722,    28.742778,   4.73),  \
  "Kap Peg":                     (   21.744083,    25.645000,   4.13),  \
  "Mu Cep":                      (   21.725111,    58.780000,   4.08),  \
  "Lam Cap":                     (   21.775583,   -11.365833,   5.58),  \
  "Deneb Algedi":                (   21.784000,   -16.127222,   2.87),  \
  "The PsA":                     (   21.795611,   -30.898333,   5.01),  \
  "Omi Ind":                     (   21.846417,   -69.629444,   5.53),  \
  "Nu Cep":                      (   21.757472,    61.120833,   4.29),  \
  "Mu Cap":                      (   21.888278,   -13.551667,   5.08),  \
  "Al Dhanab":                   (   21.898806,   -37.365000,   3.01),  \
  "Pi Ind":                      (   21.937222,   -57.899444,   6.19),  \
  "Del Ind":                     (   21.965306,   -54.992500,   4.40),  \
  "Kap Ind":                     (   21.975028,   -59.012222,   6.12),  \
  "Eta PsA":                     (   22.013944,   -28.453611,   5.42),  \
  "Eps Ind":                     (   22.056000,   -56.786111,   4.69),  \
  "Omi Aqr":                     (   22.055250,    -2.155278,   4.69),  \
  "Lam Gru":                     (   22.101917,   -39.543333,   4.46),  \
  "Nu Peg":                      (   22.094667,     5.058611,   4.84),  \
  "Sadalmeilk":                  (   22.096389,    -0.319722,   2.96),  \
  "Xi Cep":                      (   22.063167,    64.627778,   4.29),  \
  "Iot Aqr":                     (   22.107278,   -13.869722,   4.27),  \
  "Al Nair":                     (   22.137222,   -46.961111,   1.74),  \
  "Iot Peg":                     (   22.116861,    25.345000,   3.76),  \
  "Mu PsA":                      (   22.139722,   -32.988611,   4.50),  \
  "Ups PsA":                     (   22.140556,   -34.043889,   4.99),  \
  "Tau PsA":                     (   22.169111,   -32.548333,   4.92),  \
  "Pi Peg":                      (   22.153778,    33.172222,   5.58),  \
  "Baham":                       (   22.170000,     6.197778,   3.53),  \
  "Zet Cep":                     (   22.180917,    58.201111,   3.35),  \
  "Lam Cep":                     (   22.191861,    59.414444,   5.04),  \
  "Psi Oct":                     (   22.297361,   -77.511667,   5.51),  \
  "Lam PsA":                     (   22.238556,   -27.766944,   5.43),  \
  "Eps Oct":                     (   22.333750,   -80.439722,   5.10),  \
  "Mu Gru":                      (   22.260250,   -41.346667,   4.79),  \
  "Eps Cep":                     (   22.250556,    57.043611,   4.19),  \
  "Ancha":                       (   22.280556,    -7.783333,   4.16),  \
  "Alp Tuc":                     (   22.308361,   -60.259722,   2.86),  \
  "Ups Oct":                     (   22.527056,   -85.967222,   5.77),  \
  "Rho Aqr":                     (   22.336639,    -7.821111,   5.37),  \
  "Nu Ind":                      (   22.410222,   -72.255556,   5.29),  \
  "Sadalachbia":                 (   22.360944,    -1.387222,   3.84),  \
  "Pi Gru":                      (   22.378861,   -45.947778,   6.62),  \
  "Bet Lac":                     (   22.392667,    52.229167,   4.43),  \
  "Pi Aqr":                      (   22.421278,     1.377500,   4.66),  \
  "Del Tuc":                     (   22.455556,   -64.966389,   4.48),  \
  "Nu Gru":                      (   22.477556,   -39.131944,   5.47),  \
  "Del Gru":                     (   22.487833,   -43.495556,   3.97),  \
  "Zet Aqr":                     (   22.480472,    -0.020278,   4.59),  \
  "Zet PsA":                     (   22.514917,   -26.073611,   6.43),  \
  "Del Cep":                     (   22.486194,    58.415278,   3.75),  \
  "Sig Aqr":                     (   22.510778,   -10.678056,   4.82),  \
  "Bet PsA":                     (   22.525083,   -32.346111,   4.29),  \
  "Kalb Rai":                    (   22.445139,    78.785833,   5.83),  \
  "Nu Tuc":                      (   22.550028,   -61.982222,   4.81),  \
  "Alp Lac":                     (   22.521528,    50.282500,   3.77),  \
  "Ups Aqr":                     (   22.578222,   -20.708333,   5.20),  \
  "Eta Aqr":                     (   22.589278,    -0.117500,   4.02),  \
  "Sig Gru":                     (   22.608139,   -40.582778,   6.28),  \
  "Situla":                      (   22.629278,    -4.228056,   5.03),  \
  "Eps PsA":                     (   22.677611,   -27.043611,   4.17),  \
  "Bet Oct":                     (   22.767583,   -81.381667,   4.15),  \
  "Homam":                       (   22.691028,    10.831389,   3.40),  \
  "Bet Gru":                     (   22.711139,   -46.884722,   2.10),  \
  "Omi Peg":                     (   22.695944,    29.307500,   4.79),  \
  "Rho Gru":                     (   22.725000,   -41.414444,   4.85),  \
  "Matar":                       (   22.716694,    30.221389,   2.94),  \
  "Eta Gru":                     (   22.760528,   -53.500278,   4.85),  \
  "Xi Oct":                      (   22.839694,   -80.124167,   5.35),  \
  "Xi Peg":                      (   22.778222,    12.172778,   4.19),  \
  "Lam Peg":                     (   22.775528,    23.565556,   3.95),  \
  "Tau Aqr":                     (   22.795222,   -14.056389,   5.66),  \
  "Eps Gru":                     (   22.809250,   -51.316944,   3.49),  \
  "Mu Peg":                      (   22.833389,    24.601667,   3.48),  \
  "Iot Cep":                     (   22.828000,    66.200556,   3.52),  \
  "Gam PsA":                     (   22.875444,   -32.875556,   4.46),  \
  "Sig Peg":                     (   22.873361,     9.835556,   5.16),  \
  "Lam Aqr":                     (   22.876917,    -7.579722,   3.74),  \
  "Tau Gru":                     (   22.893861,   -48.598056,   6.04),  \
  "Rho Ind":                     (   22.910944,   -70.073611,   6.05),  \
  "Skat":                        (   22.910833,   -15.820833,   3.27),  \
  "Rho Peg":                     (   22.920472,     8.815833,   4.90),  \
  "Del PsA":                     (   22.932472,   -32.539722,   4.21),  \
  "Fomalhaut":                   (   22.960861,   -29.622222,   1.16),  \
  "Zet Gru":                     (   23.014667,   -52.754167,   4.12),  \
  "Omi And":                     (   23.032028,    42.326111,   3.62),  \
  "Pi PsA":                      (   23.058278,   -34.749444,   5.11),  \
  "Fum al Samakah":              (   23.064611,     3.820000,   4.53),  \
  "Kap Gru":                     (   23.077667,   -53.965000,   5.37),  \
  "Scheat":                      (   23.062917,    28.082778,   2.42),  \
  "Markab":                      (   23.079361,    15.205278,   2.49),  \
  "The Gru":                     (   23.114667,   -43.520556,   4.28),  \
  "Ups Gru":                     (   23.114889,   -38.892222,   5.61),  \
  "Pi Cep":                      (   23.131639,    75.387500,   4.41),  \
  "Iot Gru":                     (   23.172667,   -45.246667,   3.90),  \
  "Phi Aqr":                     (   23.238722,    -6.048889,   4.22),  \
  "Psi Aqr":                     (   23.264861,    -9.087778,   4.21),  \
  "Gam Tuc":                     (   23.290500,   -58.235833,   3.99),  \
  "Chi Aqr":                     (   23.280806,    -7.726667,   5.06),  \
  "Gam Psc":                     (   23.286083,     3.282222,   3.69),  \
  "Phi Gru":                     (   23.302750,   -40.824444,   5.53),  \
  "Tau Oct":                     (   23.467694,   -87.482222,   5.49),  \
  "Gam Scl":                     (   23.313722,   -32.531944,   4.41),  \
  "Omi Cep":                     (   23.310417,    68.111667,   4.75),  \
  "Tau Peg":                     (   23.343944,    23.740278,   4.60),  \
  "Ups Peg":                     (   23.423000,    23.404167,   4.40),  \
  "Omi Gru":                     (   23.443500,   -52.721667,   5.52),  \
  "Kap Psc":                     (   23.448889,     1.255556,   4.94),  \
  "The Psc":                     (   23.466139,     6.378889,   4.28),  \
  "Bet Scl":                     (   23.549528,   -37.818333,   4.37),  \
  "Iot Phe":                     (   23.584611,   -42.615000,   4.71),  \
  "Lam And":                     (   23.626083,    46.458056,   3.82),  \
  "Iot And":                     (   23.635611,    43.268056,   4.29),  \
  "The Phe":                     (   23.657778,   -46.637778,   6.09),  \
  "Ome Aqr":                     (   23.663083,   -14.221667,   5.00),  \
  "Iot Psc":                     (   23.665833,     5.626389,   4.13),  \
  "Gam Cep":                     (   23.655778,    77.632500,   3.21),  \
  "Mu Scl":                      (   23.677278,   -32.073056,   5.31),  \
  "Kap And":                     (   23.673472,    44.333889,   4.14),  \
  "Lam Psc":                     (   23.700778,     1.780000,   4.50),  \
  "Psi And":                     (   23.767250,    46.420278,   4.95),  \
  "Sig Phe":                     (   23.787778,   -50.226667,   5.18),  \
  "Tau Cas":                     (   23.784306,    58.651944,   4.87),  \
  "Del Scl":                     (   23.815444,   -28.130278,   4.57),  \
  "Phi Peg":                     (   23.874806,    19.120278,   5.08),  \
  "Rho Cas":                     (   23.906389,    57.499444,   4.54),  \
  "Eta Tuc":                     (   23.959778,   -64.298333,   5.00),  \
  "Psi Peg":                     (   23.962639,    25.141389,   4.66),  \
  "Pi Phe":                      (   23.982167,   -52.745833,   5.13),  \
  "Sig Cas":                     (   23.983472,    55.755000,   4.88),  \
  "Ome Psc":                     (   23.988528,     6.863333,   4.01),  \
  "Eps Tuc":                     (   23.998611,   -65.577222,   4.50),  \
  "Tau Phe":                     (    0.017917,   -48.810000,   5.71),  \
  "The Oct":                     (    0.026583,   -77.065833,   4.78),  \
  "Zet Scl":                     (    0.038861,   -29.720278,   5.01),  \
}



# -----------------------------------------------------------------------
#
# Constellation Stick-figures -- this is just a list of line segments between a
# pair of points in the sky specified as right ascention and declination (J2000).
# The table below is a list of touples specifying the two points as four
# coordinates expressed as fractional degrees.  For convenience, the table has
# been organized by constellation, but the program doesn't care; it deals with
# each line segment as an entity without regard to whether or not the line
# shares a point in common with another line.
#
#	Constellation line segments (J2000 coordinates)
#      RA start     Dec Start       RA End        Dec End
figures = [                                                  \
  (    2.065000,    42.329722,     1.162222,    35.620556),  \
  (    1.162222,    35.620556,     0.655556,    30.860833),  \
  (    0.655556,    30.860833,     0.139722,    29.090556),  \
  (    0.139722,    29.090556,     0.614722,    33.719444),  \
  (    0.614722,    33.719444,     0.945833,    38.499444),  \
  (    0.945833,    38.499444,    23.626111,    46.458056),  \
  (   23.626111,    46.458056,    23.031944,    42.326111),  \
  (    0.945833,    38.499444,     1.158333,    47.241944),  \
# Ant
  (   10.945278,   -37.137778,    10.452500,   -31.067778),  \
  (   10.452500,   -31.067778,     9.487500,   -35.951389),  \
# Aps
  (   16.718056,   -77.517500,    16.339167,   -78.695833),  \
  (   16.339167,   -78.695833,    16.557500,   -78.897222),  \
  (   16.718056,   -77.517500,    16.557500,   -78.897222),  \
  (   16.440833,   -78.794444,    14.797778,   -79.044722),  \
# Aqr
  (   20.794722,    -9.495833,    21.525278,    -5.571111),  \
  (   21.525278,    -5.571111,    22.055278,    -2.155278),  \
  (   22.055278,    -2.155278,    22.360833,    -1.387222),  \
  (   22.360833,    -1.387222,    22.480556,    -0.020000),  \
  (   22.480556,    -0.020000,    22.589167,    -0.117500),  \
  (   22.480556,    -0.020000,    22.421389,     1.377500),  \
  (   22.421389,     1.377500,    22.876944,    -7.579722),  \
  (   22.876944,    -7.579722,    23.238611,    -6.048889),  \
  (   23.238611,    -6.048889,    23.316111,    -9.610833),  \
  (   23.316111,    -9.610833,    23.711944,   -14.545000),  \
  (   23.711944,   -14.545000,    23.766944,   -18.678056),  \
  (   23.766944,   -18.678056,    23.434167,   -20.641944),  \
  (   23.434167,   -20.641944,    23.157500,   -21.172500),  \
  (   23.157500,   -21.172500,    22.910833,   -15.820833),  \
  (   22.910833,   -15.820833,    22.826667,   -13.592500),  \
  (   22.826667,   -13.592500,    22.876944,    -7.579722),  \
  (   23.157500,   -21.172500,    22.960833,   -29.622222),  \
# Aql
  (   18.993611,    15.068333,    19.090278,    13.863333),  \
  (   19.090278,    13.863333,    19.771111,    10.613333),  \
  (   19.771111,    10.613333,    19.846389,     8.868333),  \
  (   19.846389,     8.868333,    19.921944,     6.406667),  \
  (   19.921944,     6.406667,    20.188333,    -0.821389),  \
  (   20.188333,    -0.821389,    19.874444,     1.005556),  \
  (   19.874444,     1.005556,    19.611944,    -1.286389),  \
  (   19.611944,    -1.286389,    19.104167,    -4.882500),  \
  (   19.104167,    -4.882500,    19.425000,     3.114722),  \
  (   19.425000,     3.114722,    19.771111,    10.613333),  \
  (   19.104167,    -4.882500,    19.028056,    -5.738889),  \
# Ara
  (   18.110556,   -50.091667,    17.530833,   -49.875833),  \
  (   17.530833,   -49.875833,    17.421667,   -55.530000),  \
  (   17.421667,   -55.530000,    17.423333,   -56.377778),  \
  (   17.423333,   -56.377778,    17.518333,   -60.683889),  \
  (   17.421667,   -55.530000,    16.976944,   -55.990278),  \
  (   16.976944,   -55.990278,    16.993056,   -53.160556),  \
  (   16.976944,   -55.990278,    16.829722,   -59.041389),  \
# Ari
  (    3.193889,    19.726667,     2.119444,    23.462500),  \
  (    2.119444,    23.462500,     1.910556,    20.808056),  \
  (    1.910556,    20.808056,     1.892222,    19.293889),  \
# Aur
  (    5.438333,    28.607500,     5.995278,    37.212500),  \
  (    5.995278,    37.212500,     5.992222,    44.947500),  \
  (    5.992222,    44.947500,     5.992222,    54.284722),  \
  (    5.992222,    54.284722,     5.278056,    45.998056),  \
  (    5.278056,    45.998056,     5.108611,    41.234444),  \
  (    5.108611,    41.234444,     4.950000,    33.166111),  \
  (    4.950000,    33.166111,     5.438333,    28.607500),  \
  (    5.992222,    44.947500,     5.278056,    45.998056),  \
# Boo
  (   14.261111,    19.182500,    14.685833,    13.728333),  \
  (   14.261111,    19.182500,    13.911389,    18.397778),  \
  (   13.911389,    18.397778,    13.824722,    15.797778),  \
  (   14.261111,    19.182500,    14.749722,    27.074167),  \
  (   14.749722,    27.074167,    15.258333,    33.314722),  \
  (   15.258333,    33.314722,    15.032500,    40.390556),  \
  (   15.032500,    40.390556,    14.578056,    29.745000),  \
  (   14.578056,    29.745000,    14.261111,    19.182500),  \
  (   15.032500,    40.390556,    14.273056,    46.088333),  \
  (   14.273056,    46.088333,    14.420000,    51.850833),  \
# Cae
  (    5.073333,   -35.482778,     4.701111,   -37.144444),  \
  (    4.701111,   -37.144444,     4.676111,   -41.863889),  \
  (    4.676111,   -41.863889,     4.513889,   -44.953889),  \
# Cam
  (    6.895000,    68.888333,     6.214167,    65.718333),  \
  (    6.214167,    65.718333,     4.900833,    66.342778),  \
  (    4.900833,    66.342778,     3.839444,    71.332222),  \
  (    4.900833,    66.342778,     5.056944,    60.442222),  \
  (    5.056944,    60.442222,     4.954722,    53.752222),  \
# Cnc
  (    8.778333,    28.760000,     8.721389,    21.468611),  \
  (    8.721389,    21.468611,     8.744722,    18.154167),  \
  (    8.744722,    18.154167,     8.974722,    11.857778),  \
  (    8.744722,    18.154167,     8.445556,    12.654444),  \
  (    8.445556,    12.654444,     8.275278,     9.185556),  \
# Cvn
  (   13.292500,    40.572500,    13.228611,    40.152778),  \
  (   13.228611,    40.152778,    12.933889,    38.318333),  \
  (   12.933889,    38.318333,    12.562500,    41.357500),  \
# Cma
  (    6.752500,   -16.716111,     7.062778,   -15.633333),  \
  (    6.752500,   -16.716111,     6.378333,   -17.955833),  \
  (    6.752500,   -16.716111,     6.892500,   -20.224167),  \
  (    6.892500,   -20.224167,     7.050556,   -23.833333),  \
  (    7.050556,   -23.833333,     7.140000,   -26.393333),  \
  (    7.140000,   -26.393333,     7.028611,   -27.934722),  \
  (    7.028611,   -27.934722,     6.977222,   -28.972222),  \
  (    6.977222,   -28.972222,     6.338611,   -30.063333),  \
  (    7.140000,   -26.393333,     7.276389,   -27.881111),  \
  (    7.276389,   -27.881111,     7.401667,   -29.303056),  \
# Cmi
  (    7.655000,     5.225000,     7.452500,     8.289444),  \
# Cap
  (   21.783889,   -16.127222,    21.668333,   -16.662222),  \
  (   21.668333,   -16.662222,    21.370833,   -16.834444),  \
  (   21.370833,   -16.834444,    21.099167,   -17.232778),  \
  (   21.099167,   -17.232778,    20.294167,   -12.508333),  \
  (   20.294167,   -12.508333,    20.346389,   -14.785000),  \
  (   20.346389,   -14.785000,    20.768333,   -25.270833),  \
  (   20.768333,   -25.270833,    20.863611,   -26.919167),  \
  (   20.863611,   -26.919167,    21.118889,   -25.005833),  \
  (   21.118889,   -25.005833,    21.444444,   -22.411389),  \
  (   21.444444,   -22.411389,    21.618056,   -19.465833),  \
  (   21.618056,   -19.465833,    21.783889,   -16.127222),  \
# Car
  (    6.399167,   -52.695833,     7.946389,   -52.982222),  \
  (    7.946389,   -52.982222,     8.375278,   -59.509722),  \
  (    8.375278,   -59.509722,     9.182778,   -58.966944),  \
  (    9.182778,   -58.966944,     9.284722,   -59.275278),  \
  (    9.284722,   -59.275278,    10.456667,   -57.638889),  \
  (   10.456667,   -57.638889,    10.533611,   -61.685278),  \
  (   10.533611,   -61.685278,    10.715833,   -64.394444),  \
  (   10.715833,   -64.394444,    10.228889,   -70.038056),  \
  (   10.228889,   -70.038056,     9.220000,   -69.717222),  \
  (    9.220000,   -69.717222,     9.785000,   -65.071944),  \
  (    9.785000,   -65.071944,     9.284722,   -59.275278),  \
# Cas
  (    1.906667,    63.670000,     1.430278,    60.235278),  \
  (    1.430278,    60.235278,     0.945278,    60.716667),  \
  (    0.945278,    60.716667,     0.675278,    56.537222),  \
  (    0.675278,    56.537222,     0.153056,    59.149722),  \
# Cen
  (   14.660000,   -60.835278,    14.063611,   -60.373056),  \
  (   14.063611,   -60.373056,    13.664722,   -53.466389),  \
  (   13.664722,   -53.466389,    12.691944,   -48.959722),  \
  (   12.691944,   -48.959722,    12.139444,   -50.722500),  \
  (   12.139444,   -50.722500,    11.350000,   -54.491111),  \
  (   11.350000,   -54.491111,    11.596389,   -63.019722),  \
  (   13.664722,   -53.466389,    13.925556,   -47.288333),  \
  (   13.925556,   -47.288333,    14.591667,   -42.157778),  \
  (   14.591667,   -42.157778,    14.111389,   -36.370000),  \
  (   14.111389,   -36.370000,    13.343333,   -36.712222),  \
  (   13.343333,   -36.712222,    12.691944,   -48.959722),  \
  (   14.591667,   -42.157778,    14.986111,   -42.104167),  \
# Cep
  (   23.655833,    77.632500,    21.477778,    70.560833),  \
  (   21.477778,    70.560833,    21.309722,    62.585556),  \
  (   21.309722,    62.585556,    22.180833,    58.201111),  \
  (   22.180833,    58.201111,    22.828056,    66.200556),  \
  (   22.828056,    66.200556,    23.655833,    77.632500),  \
  (   21.477778,    70.560833,    22.828056,    66.200556),  \
# Cet
  (    0.323889,    -8.823889,     0.726389,   -17.986667),  \
  (    0.726389,   -17.986667,     1.143056,   -10.182222),  \
  (    1.143056,   -10.182222,     1.400278,    -8.183333),  \
  (    1.400278,    -8.183333,     1.857778,   -10.335000),  \
  (    1.857778,   -10.335000,     2.735278,   -13.858611),  \
  (    1.857778,   -10.335000,     1.734444,   -15.937500),  \
  (    1.734444,   -15.937500,     2.000000,   -21.077778),  \
  (    1.857778,   -10.335000,     2.322500,    -2.977500),  \
  (    2.322500,    -2.977500,     2.658056,     0.328611),  \
  (    2.658056,     0.328611,     2.721667,     3.235833),  \
  (    2.721667,     3.235833,     3.038056,     4.089722),  \
  (    3.038056,     4.089722,     2.995278,     8.907500),  \
  (    2.995278,     8.907500,     2.749167,    10.114167),  \
  (    2.749167,    10.114167,     2.469444,     8.460000),  \
  (    2.469444,     8.460000,     2.721667,     3.235833),  \
# Cha -- has no figure
# Cir
  (   15.389722,   -59.320833,    14.708333,   -64.975278),  \
  (   14.708333,   -64.975278,    15.291944,   -58.801111),  \
# Col
  (    5.985833,   -42.815278,     5.849444,   -35.768333),  \
  (    5.849444,   -35.768333,     5.958889,   -35.283333),  \
  (    5.958889,   -35.283333,     6.368611,   -33.436389),  \
  (    5.849444,   -35.768333,     5.660833,   -34.074167),  \
  (    5.660833,   -34.074167,     5.520278,   -35.470556),  \
# Com
  (   13.166389,    17.529444,    13.197778,    27.878056),  \
  (   13.197778,    27.878056,    12.448889,    28.268333),  \
# Cra
  (   18.978611,   -37.107500,    19.106944,   -37.063333),  \
  (   19.106944,   -37.063333,    19.157778,   -37.904444),  \
  (   19.157778,   -37.904444,    19.167222,   -39.340833),  \
  (   19.167222,   -39.340833,    19.139167,   -40.496667),  \
  (   19.139167,   -40.496667,    19.051944,   -42.095278),  \
  (   19.051944,   -42.095278,    18.814167,   -43.680000),  \
  (   18.814167,   -43.680000,    18.558333,   -42.312500),  \
# Crb
  (   16.024167,    29.851111,    15.959722,    26.877778),  \
  (   15.959722,    26.877778,    15.826667,    26.068333),  \
  (   15.826667,    26.068333,    15.712500,    26.295556),  \
  (   15.712500,    26.295556,    15.578056,    26.714722),  \
  (   15.578056,    26.714722,    15.463889,    29.105833),  \
  (   15.463889,    29.105833,    15.548889,    31.359167),  \
# Crv
  (   12.140278,   -24.728889,    12.168889,   -22.619722),  \
  (   12.168889,   -22.619722,    12.573056,   -23.396667),  \
  (   12.573056,   -23.396667,    12.497778,   -16.515556),  \
  (   12.497778,   -16.515556,    12.263333,   -17.541944),  \
  (   12.263333,   -17.541944,    12.168889,   -22.619722),  \
# Crt
  (   10.827222,   -16.193611,    10.996389,   -18.298889),  \
  (   10.996389,   -18.298889,    11.194444,   -22.825833),  \
  (   10.996389,   -18.298889,    11.366944,   -16.225000),  \
  (   11.933611,   -17.150833,    11.746111,   -18.350833),  \
  (   11.746111,   -18.350833,    11.414722,   -17.683889),  \
  (   11.414722,   -17.683889,    11.322500,   -14.778611),  \
  (   11.322500,   -14.778611,    11.410278,   -10.859444),  \
  (   11.410278,   -10.859444,    11.611389,    -9.802222),  \
# Cru
  (   12.795278,   -59.688611,    12.252500,   -58.748889),  \
  (   12.443333,   -63.098889,    12.519444,   -57.113056),  \
# Cyg
  (   20.690556,    45.280278,    20.370556,    40.256667),  \
  (   20.370556,    40.256667,    20.770278,    33.970278),  \
  (   20.370556,    40.256667,    19.749722,    45.130833),  \
  (   20.370556,    40.256667,    19.938333,    35.083333),  \
  (   19.938333,    35.083333,    19.511944,    27.959722),  \
# Del
  (   20.625833,    14.595278,    20.553611,    11.303333),  \
  (   20.625833,    14.595278,    20.724444,    15.074444),  \
  (   20.724444,    15.074444,    20.777778,    16.124167),  \
  (   20.777778,    16.124167,    20.660556,    15.911944),  \
  (   20.660556,    15.911944,    20.625833,    14.595278),  \
# Dor
  (    5.746111,   -65.735556,     5.560556,   -62.489722),  \
  (    5.560556,   -62.489722,     4.533333,   -55.045000),  \
  (    4.533333,   -55.045000,     4.267222,   -51.486667),  \
# Dra
  (   11.523333,    69.331111,    12.558056,    69.788333),  \
  (   12.558056,    69.788333,    14.073056,    64.375833),  \
  (   14.073056,    64.375833,    15.415556,    58.966111),  \
  (   15.415556,    58.966111,    16.031389,    58.565278),  \
  (   16.031389,    58.565278,    16.400000,    61.514167),  \
  (   16.400000,    61.514167,    17.146389,    65.714722),  \
  (   17.146389,    65.714722,    18.350833,    72.732778),  \
  (   18.350833,    72.732778,    19.259167,    73.355556),  \
  (   19.259167,    73.355556,    19.802778,    70.267778),  \
  (   19.802778,    70.267778,    20.046944,    67.873611),  \
  (   20.046944,    67.873611,    18.853333,    59.388333),  \
  (   18.853333,    59.388333,    17.892222,    56.872778),  \
  (   17.892222,    56.872778,    17.943333,    51.488889),  \
  (   17.943333,    51.488889,    17.507222,    52.301389),  \
  (   17.507222,    52.301389,    17.537778,    55.173056),  \
  (   17.537778,    55.173056,    17.892222,    56.872778),  \
  (   17.892222,    56.872778,    19.344444,    65.714722),  \
  (   19.344444,    65.714722,    19.209167,    67.661667),  \
  (   19.209167,    67.661667,    18.346111,    71.337778),  \
  (   18.346111,    71.337778,    17.146389,    65.714722),  \
# Equ
  (   21.263611,     5.247778,    21.241389,    10.006944),  \
  (   21.241389,    10.006944,    21.172500,    10.131667),  \
# Eri
  (    5.130833,    -5.086389,     4.758333,    -3.254722),  \
  (    4.758333,    -3.254722,     4.605278,    -3.352500),  \
  (    4.605278,    -3.352500,     4.197778,    -6.837500),  \
  (    4.197778,    -6.837500,     3.967222,   -13.508611),  \
  (    3.967222,   -13.508611,     3.769167,   -12.101667),  \
  (    3.769167,   -12.101667,     3.720833,    -9.763333),  \
  (    3.720833,    -9.763333,     3.548889,    -9.458333),  \
  (    3.548889,    -9.458333,     3.263889,    -8.819722),  \
  (    3.263889,    -8.819722,     2.940556,    -8.898056),  \
  (    2.940556,    -8.898056,     2.735278,   -13.858611),  \
  (    2.735278,   -13.858611,     2.751667,   -18.572500),  \
  (    2.751667,   -18.572500,     3.040000,   -23.624444),  \
  (    3.040000,   -23.624444,     3.325278,   -21.757778),  \
  (    3.325278,   -21.757778,     3.563056,   -21.632778),  \
  (    3.563056,   -21.632778,     3.780833,   -23.249722),  \
  (    3.780833,   -23.249722,     3.895278,   -24.612500),  \
  (    3.895278,   -24.612500,     3.998889,   -24.016389),  \
  (    3.998889,   -24.016389,     4.558611,   -29.766667),  \
  (    4.558611,   -29.766667,     4.592500,   -30.562222),  \
  (    4.592500,   -30.562222,     4.400556,   -34.016944),  \
  (    4.400556,   -34.016944,     4.298333,   -33.798333),  \
  (    4.298333,   -33.798333,     3.810000,   -37.620556),  \
  (    3.810000,   -37.620556,     3.713889,   -37.313611),  \
  (    3.713889,   -37.313611,     2.971111,   -40.304722),  \
  (    2.971111,   -40.304722,     2.677778,   -39.855556),  \
  (    2.677778,   -39.855556,     2.663333,   -42.891667),  \
  (    2.663333,   -42.891667,     2.449722,   -47.703889),  \
  (    2.449722,   -47.703889,     2.275278,   -51.512222),  \
  (    2.275278,   -51.512222,     1.932778,   -51.608889),  \
  (    1.932778,   -51.608889,     1.628611,   -57.236667),  \
# For -- has no figure
# Gem
  (    6.754722,    12.895556,     6.628611,    16.399167),  \
  (    6.628611,    16.399167,     7.068611,    20.570278),  \
  (    7.068611,    20.570278,     7.335278,    21.982222),  \
  (    7.335278,    21.982222,     7.755278,    28.026111),  \
  (    7.755278,    28.026111,     7.576667,    31.888333),  \
  (    7.576667,    31.888333,     6.732222,    25.131111),  \
  (    6.732222,    25.131111,     6.382778,    22.513611),  \
  (    6.382778,    22.513611,     6.248056,    22.506667),  \
  (    6.248056,    22.506667,     6.068611,    23.263333),  \
# Gru
  (   21.898889,   -37.365000,    21.988333,   -38.395278),  \
  (   21.988333,   -38.395278,    22.101944,   -39.543333),  \
  (   22.101944,   -39.543333,    22.260278,   -41.346667),  \
  (   22.260278,   -41.346667,    22.487778,   -43.495556),  \
  (   22.487778,   -43.495556,    22.137222,   -46.961111),  \
  (   22.487778,   -43.495556,    22.711111,   -46.884722),  \
  (   22.711111,   -46.884722,    23.172778,   -45.246667),  \
  (   23.172778,   -45.246667,    23.110833,   -43.503611),  \
  (   22.711111,   -46.884722,    22.809167,   -51.316944),  \
  (   22.809167,   -51.316944,    23.014722,   -52.754167),  \
# Her
  (   18.125833,    28.762500,    17.962778,    29.247778),  \
  (   17.962778,    29.247778,    17.774444,    27.720556),  \
  (   17.774444,    27.720556,    17.512222,    26.110556),  \
  (   17.512222,    26.110556,    17.250556,    24.839167),  \
  (   17.250556,    24.839167,    17.244167,    14.390278),  \
  (   17.250556,    24.839167,    17.004722,    30.926389),  \
  (   17.004722,    30.926389,    16.688056,    31.603056),  \
  (   16.688056,    31.603056,    16.503611,    21.489722),  \
  (   16.503611,    21.489722,    16.365278,    19.153056),  \
  (   16.688056,    31.603056,    16.715000,    38.922222),  \
  (   16.715000,    38.922222,    16.568333,    42.436944),  \
  (   16.568333,    42.436944,    16.328889,    46.313333),  \
  (   16.328889,    46.313333,    16.146111,    44.935000),  \
  (   16.146111,    44.935000,    15.878056,    42.451667),  \
  (   16.715000,    38.922222,    17.250833,    36.809167),  \
  (   17.250833,    36.809167,    17.657778,    46.006389),  \
  (   17.250833,    36.809167,    17.394722,    37.145833),  \
  (   17.394722,    37.145833,    17.937500,    37.250556),  \
  (   17.004722,    30.926389,    17.250833,    36.809167),  \
# Hor
  (    4.233333,   -42.294444,     2.709444,   -50.800278),  \
  (    2.709444,   -50.800278,     2.623333,   -52.543056),  \
  (    2.623333,   -52.543056,     2.694444,   -54.550000),  \
  (    2.677778,   -54.550000,     3.060278,   -59.737778),  \
  (    3.060278,   -59.737778,     2.980000,   -64.071389),  \
# Hya
  (   14.106111,   -26.682500,    13.315278,   -23.171667),  \
  (   13.315278,   -23.171667,    11.881944,   -33.908056),  \
  (   11.881944,   -33.908056,    11.550000,   -31.857778),  \
  (   11.550000,   -31.857778,    10.827222,   -16.193611),  \
  (   10.827222,   -16.193611,    10.434722,   -16.836389),  \
  (   10.434722,   -16.836389,    10.176389,   -12.354167),  \
  (   10.176389,   -12.354167,     9.858056,   -14.846667),  \
  (    9.858056,   -14.846667,     9.459722,    -8.658611),  \
  (    9.459722,    -8.658611,     9.664167,    -1.142778),  \
  (    9.664167,    -1.142778,     9.239444,     2.314167),  \
  (    9.239444,     2.314167,     8.923333,     5.945556),  \
  (    8.923333,     5.945556,     8.779722,     6.418889),  \
  (    8.779722,     6.418889,     8.627500,     5.703611),  \
  (    8.627500,     5.703611,     8.645833,     3.341389),  \
  (    8.645833,     3.341389,     8.720556,     3.398611),  \
  (    8.720556,     3.398611,     8.923333,     5.945556),  \
# Hyi
  (    1.979444,   -61.569722,     3.787222,   -74.238889),  \
  (    3.787222,   -74.238889,     0.429167,   -77.254167),  \
  (    0.429167,   -77.254167,     1.979444,   -61.569722),  \
# Ind
  (   20.626111,   -47.291389,    21.331111,   -53.449722),  \
  (   21.331111,   -53.449722,    20.913611,   -58.454167),  \
  (   21.965278,   -54.992500,    21.331111,   -53.449722),  \
# Lac
  (   22.266111,    37.748889,    22.675278,    44.276389),  \
  (   22.675278,    44.276389,    22.350556,    46.536667),  \
  (   22.350556,    46.536667,    22.492222,    47.706944),  \
  (   22.492222,    47.706944,    22.408611,    49.476389),  \
  (   22.408611,    49.476389,    22.521667,    50.282500),  \
  (   22.521667,    50.282500,    22.392778,    52.229167),  \
# Leo
  (    9.764167,    23.774167,     9.879444,    26.006944),  \
  (    9.879444,    26.006944,    10.278056,    23.417222),  \
  (   10.278056,    23.417222,    10.332778,    19.841667),  \
  (   10.332778,    19.841667,    10.122222,    16.762778),  \
  (   10.122222,    16.762778,    10.139444,    11.967222),  \
  (   10.139444,    11.967222,    11.237222,    15.429444),  \
  (   11.237222,    15.429444,    11.817778,    14.571944),  \
  (   11.817778,    14.571944,    11.235278,    20.523611),  \
  (   11.235278,    20.523611,    11.237222,    15.429444),  \
# Lmi
  (   10.888611,    34.215000,    10.464722,    36.707222),  \
  (   10.464722,    36.707222,    10.123889,    35.244722),  \
# Lep
  (    5.940000,   -14.167778,     5.782500,   -14.821944),  \
  (    5.782500,   -14.821944,     5.545556,   -17.822222),  \
  (    5.545556,   -17.822222,     5.215556,   -16.205556),  \
  (    5.545556,   -17.822222,     5.855278,   -20.879167),  \
  (    5.855278,   -20.879167,     5.741111,   -22.448333),  \
  (    5.741111,   -22.448333,     5.470833,   -20.759444),  \
  (    5.470833,   -20.759444,     5.091111,   -22.371111),  \
  (    5.470833,   -20.759444,     5.545556,   -17.822222),  \
# Lib
  (   15.644167,   -29.777778,    15.617222,   -28.135000),  \
  (   15.617222,   -28.135000,    15.067778,   -25.281944),  \
  (   15.067778,   -25.281944,    14.848056,   -16.041667),  \
  (   14.848056,   -16.041667,    15.283333,    -9.383056),  \
  (   15.283333,    -9.383056,    15.592222,   -14.789444),  \
  (   15.592222,   -14.789444,    15.067778,   -25.281944),  \
# Lup
  (   14.698889,   -47.388333,    15.204722,   -52.099167),  \
  (   15.204722,   -52.099167,    15.308889,   -47.875000),  \
  (   15.308889,   -47.875000,    15.378056,   -44.689444),  \
  (   15.378056,   -44.689444,    15.585833,   -41.166944),  \
  (   15.585833,   -41.166944,    15.634167,   -42.567500),  \
  (   15.634167,   -42.567500,    15.686389,   -44.661111),  \
  (   15.686389,   -44.661111,    16.110000,   -36.802222),  \
  (   16.110000,   -36.802222,    15.849444,   -33.627222),  \
  (   15.849444,   -33.627222,    15.363333,   -36.261389),  \
  (   15.363333,   -36.261389,    15.356111,   -40.647500),  \
  (   15.356111,   -40.647500,    14.975556,   -43.133889),  \
  (   14.975556,   -43.133889,    14.698889,   -47.388333),  \
# Lyn
  (    6.326944,    59.010833,     6.954722,    58.422500),  \
  (    6.954722,    58.422500,     7.445278,    49.211389),  \
  (    7.445278,    49.211389,     8.140833,    51.506667),  \
  (    8.140833,    51.506667,     8.380556,    43.188056),  \
  (    8.380556,    43.188056,     9.108889,    38.452222),  \
  (    9.108889,    38.452222,     9.314167,    36.802500),  \
  (    9.314167,    36.802500,     9.350833,    34.392500),  \
# Lyr
  (   18.738889,    39.670000,    18.615556,    38.783611),  \
  (   18.615556,    38.783611,    18.746111,    37.605000),  \
  (   18.746111,    37.605000,    18.908333,    36.898889),  \
  (   18.908333,    36.898889,    18.982500,    32.689444),  \
  (   18.982500,    32.689444,    18.834722,    33.362778),  \
  (   18.834722,    33.362778,    18.746111,    37.605000),  \
# Men
  (    5.045278,   -71.314444,     4.919722,   -74.936944),  \
  (    4.919722,   -74.936944,     5.531389,   -76.341111),  \
  (    5.531389,   -76.341111,     6.170556,   -74.753056),  \
# Mic
  (   21.346111,   -40.809444,    21.298889,   -32.172500),  \
  (   21.298889,   -32.172500,    21.021389,   -32.257778),  \
  (   21.021389,   -32.257778,    20.832778,   -33.779722),  \
# Mon
  (    6.247500,    -6.274722,     6.480278,    -7.033056),  \
  (    6.480278,    -7.033056,     7.197778,    -0.492778),  \
  (    7.197778,    -0.492778,     7.687500,    -9.551111),  \
  (    7.687500,    -9.551111,     8.143333,    -2.983889),  \
# Mus
  (   11.760000,   -66.728889,    12.619722,   -69.135556),  \
  (   12.619722,   -69.135556,    12.771389,   -68.108056),  \
  (   12.771389,   -68.108056,    13.037778,   -71.548889),  \
  (   13.037778,   -71.548889,    12.541111,   -72.133056),  \
  (   12.541111,   -72.133056,    12.619722,   -69.135556),  \
# Nor
  (   16.053611,   -49.229722,    16.108056,   -45.173333),  \
  (   16.108056,   -45.173333,    16.453056,   -47.554722),  \
  (   16.453056,   -47.554722,    16.330556,   -50.155556),  \
  (   16.330556,   -50.155556,    16.053611,   -49.229722),  \
# Oct
  (   14.448611,   -83.667778,    21.691389,   -77.390000),  \
  (   21.691389,   -77.390000,    22.767778,   -81.381667),  \
  (   22.767778,   -81.381667,    14.448611,   -83.667778),  \
# Oph
  (   16.239167,    -3.694444,    16.305278,    -4.692500),  \
  (   16.305278,    -4.692500,    16.619444,   -10.567222),  \
  (   16.619444,   -10.567222,    17.173056,   -15.724722),  \
  (   17.173056,   -15.724722,    17.798333,     2.707222),  \
  (   17.798333,     2.707222,    17.724444,     4.567222),  \
  (   17.724444,     4.567222,    17.582222,    12.560000),  \
  (   17.582222,    12.560000,    16.961111,     9.375000),  \
  (   16.961111,     9.375000,    16.515278,     1.983889),  \
  (   16.515278,     1.983889,    16.239167,    -3.694444),  \
  (   17.798333,     2.707222,    18.010833,     2.931667),  \
  (   18.010833,     2.931667,    18.090833,     2.499444),  \
# Ori
  (    6.065278,    20.138333,     6.198889,    14.208889),  \
  (    6.198889,    14.208889,     6.039722,     9.647500),  \
  (    6.039722,     9.647500,     6.126111,    14.768333),  \
  (    6.126111,    14.768333,     5.906389,    20.276111),  \
  (    6.039722,     9.647500,     5.919444,     7.406944),  \
  (    5.919444,     7.406944,     5.580278,     9.489444),  \
  (    5.580278,     9.489444,     5.418889,     6.349722),  \
  (    5.418889,     6.349722,     4.975833,     1.714167),  \
  (    4.975833,     1.714167,     4.904167,     2.440556),  \
  (    4.904167,     2.440556,     4.853333,     5.605000),  \
  (    4.853333,     5.605000,     4.830556,     6.961389),  \
  (    4.830556,     6.961389,     4.843611,     8.900278),  \
  (    4.843611,     8.900278,     4.875556,    14.250556),  \
  (    5.919444,     7.406944,     5.679444,    -1.942778),  \
  (    5.679444,    -1.942778,     5.795833,    -9.669722),  \
  (    5.795833,    -9.669722,     5.242222,    -8.201667),  \
  (    5.242222,    -8.201667,     5.533333,    -0.299167),  \
  (    5.533333,    -0.299167,     5.418889,     6.349722),  \
# Pav
  (   21.440833,   -65.366111,    20.749444,   -66.203056),  \
  (   20.749444,   -66.203056,    20.427500,   -56.735000),  \
  (   20.749444,   -66.203056,    20.145556,   -66.181944),  \
  (   20.145556,   -66.181944,    17.762222,   -64.723889),  \
  (   17.762222,   -64.723889,    18.717222,   -71.428056),  \
  (   18.717222,   -71.428056,    20.010000,   -72.910556),  \
  (   20.010000,   -72.910556,    20.749444,   -66.203056),  \
# Peg
  (    0.139722,    29.090556,     0.220556,    15.183611),  \
  (    0.220556,    15.183611,    23.079444,    15.205278),  \
  (   23.079444,    15.205278,    23.063056,    28.082778),  \
  (   23.063056,    28.082778,     0.139722,    29.090556),  \
  (   23.079444,    15.205278,    22.778333,    12.172778),  \
  (   22.778333,    12.172778,    22.691111,    10.831389),  \
  (   22.691111,    10.831389,    22.170000,     6.197778),  \
  (   22.170000,     6.197778,    21.736389,     9.875000),  \
  (   22.166389,    33.178333,    22.716667,    30.221389),  \
  (   22.716667,    30.221389,    23.063056,    28.082778),  \
  (   23.063056,    28.082778,    22.833333,    24.601667),  \
  (   22.833333,    24.601667,    22.775556,    23.565556),  \
  (   22.775556,    23.565556,    22.116944,    25.345000),  \
  (   22.116944,    25.345000,    21.744167,    25.645000),  \
# Per
  (    3.738611,    32.288333,     3.902222,    31.883611),  \
  (    3.902222,    31.883611,     3.982778,    35.791111),  \
  (    3.982778,    35.791111,     3.964167,    40.010278),  \
  (    3.964167,    40.010278,     3.753333,    42.578611),  \
  (    3.753333,    42.578611,     3.715556,    47.787500),  \
  (    3.715556,    47.787500,     4.144444,    47.712500),  \
  (    4.144444,    47.712500,     4.248333,    48.409444),  \
  (    4.248333,    48.409444,     4.109722,    50.351389),  \
  (    3.715556,    47.787500,     3.405278,    49.861111),  \
  (    3.405278,    49.861111,     3.080000,    53.506389),  \
  (    3.080000,    53.506389,     2.845000,    55.895556),  \
  (    2.845000,    55.895556,     2.904444,    52.762500),  \
  (    2.904444,    52.762500,     3.151111,    49.613333),  \
  (    3.151111,    49.613333,     3.158333,    44.857222),  \
  (    3.158333,    44.857222,     3.136111,    40.955556),  \
  (    3.136111,    40.955556,     3.086389,    38.840278),  \
# Phe
  (    1.472778,   -43.318333,     1.520833,   -49.072778),  \
  (    1.520833,   -49.072778,     1.101389,   -46.718611),  \
  (    1.101389,   -46.718611,     1.472778,   -43.318333),  \
  (    1.101389,   -46.718611,     1.139722,   -55.245833),  \
  (    1.101389,   -46.718611,     0.438056,   -42.306111),  \
  (    0.438056,   -42.306111,     0.156944,   -45.747500),  \
# Pic
  (    5.788056,   -51.066389,     5.830556,   -56.166667),  \
  (    5.830556,   -56.166667,     6.803056,   -61.941389),  \
# Psc
  (    1.194444,    30.089722,     1.324444,    27.264167),  \
  (    1.324444,    27.264167,     1.229167,    24.583611),  \
  (    1.229167,    24.583611,     1.524722,    15.345833),  \
  (    1.524722,    15.345833,     1.756667,     9.157778),  \
  (    1.756667,     9.157778,     2.034167,     2.763611),  \
  (    2.034167,     2.763611,     1.690556,     5.487500),  \
  (    1.690556,     5.487500,     1.503056,     6.143889),  \
  (    1.503056,     6.143889,     1.049167,     7.890000),  \
  (    1.049167,     7.890000,    23.988611,     6.863333),  \
  (   23.988611,     6.863333,    23.665833,     5.626389),  \
  (   23.665833,     5.626389,    23.700833,     1.780000),  \
  (   23.700833,     1.780000,    23.448889,     1.255556),  \
  (   23.448889,     1.255556,    23.286111,     3.282222),  \
  (   23.286111,     3.282222,    23.064722,     3.820000),  \
  (   23.665833,     5.626389,    23.466111,     6.378889),  \
  (   23.466111,     6.378889,    23.286111,     3.282222),  \
# Psa
  (   22.677500,   -27.043611,    22.960833,   -29.622222),  \
  (   22.960833,   -29.622222,    22.932500,   -32.539722),  \
  (   22.932500,   -32.539722,    22.875556,   -32.875556),  \
  (   22.875556,   -32.875556,    22.525000,   -32.346111),  \
  (   22.525000,   -32.346111,    22.139722,   -32.988611),  \
  (   22.139722,   -32.988611,    21.749167,   -33.025833),  \
# Pup
  (    8.125833,   -24.304167,     7.821667,   -24.859722),  \
  (    7.821667,   -24.859722,     7.725556,   -28.411111),  \
  (    7.725556,   -28.411111,     8.059722,   -40.003333),  \
  (    8.059722,   -40.003333,     7.285833,   -37.097500),  \
  (    7.285833,   -37.097500,     7.487222,   -43.301389),  \
  (    8.059722,   -40.003333,     7.487222,   -43.301389),  \
  (    7.487222,   -43.301389,     7.225556,   -44.639722),  \
  (    7.225556,   -44.639722,     6.629444,   -43.196111),  \
  (    6.629444,   -43.196111,     6.832222,   -50.614722),  \
  (    6.832222,   -50.614722,     7.225556,   -44.639722),  \
# Pyx
  (    8.842222,   -27.710000,     8.726667,   -33.186389),  \
  (    8.726667,   -33.186389,     8.668333,   -35.308333),  \
# Ret
  (    3.736667,   -64.806944,     4.240556,   -62.473889),  \
  (    4.240556,   -62.473889,     4.274722,   -59.302222),  \
  (    4.274722,   -59.302222,     3.979167,   -61.400278),  \
  (    3.979167,   -61.400278,     4.015000,   -62.159444),  \
  (    4.015000,   -62.159444,     3.736667,   -64.806944),  \
# Sge
  (   19.979167,    19.492222,    19.789722,    18.534167),  \
  (   19.789722,    18.534167,    19.668333,    18.013889),  \
  (   19.789722,    18.534167,    19.684167,    17.476111),  \
# Sgr
  (   19.377222,   -44.458889,    19.398056,   -40.616111),  \
  (   19.398056,   -40.616111,    19.043611,   -29.880278),  \
  (   19.043611,   -29.880278,    19.115556,   -27.670556),  \
  (   19.115556,   -27.670556,    18.921111,   -26.296667),  \
  (   18.921111,   -26.296667,    18.760833,   -26.990833),  \
  (   18.760833,   -26.990833,    19.043611,   -29.880278),  \
  (   18.921111,   -26.296667,    19.078056,   -21.741667),  \
  (   19.078056,   -21.741667,    18.962222,   -21.106667),  \
  (   19.078056,   -21.741667,    19.162778,   -21.023611),  \
  (   19.162778,   -21.023611,    19.361111,   -17.847222),  \
  (   19.043611,   -29.880278,    18.402778,   -34.384722),  \
  (   18.402778,   -34.384722,    18.350000,   -29.828056),  \
  (   18.350000,   -29.828056,    18.466111,   -25.421667),  \
  (   18.466111,   -25.421667,    18.760833,   -26.990833),  \
  (   18.402778,   -34.384722,    18.096944,   -30.424167),  \
  (   18.096944,   -30.424167,    18.350000,   -29.828056),  \
# Sco
  (   17.512778,   -37.295833,    17.560278,   -37.103889),  \
  (   17.560278,   -37.103889,    17.708056,   -39.030000),  \
  (   17.708056,   -39.030000,    17.793056,   -40.126944),  \
  (   17.793056,   -40.126944,    17.621944,   -42.997778),  \
  (   17.621944,   -42.997778,    17.202500,   -43.239167),  \
  (   17.202500,   -43.239167,    16.909722,   -42.361389),  \
  (   16.909722,   -42.361389,    16.872222,   -38.017500),  \
  (   16.872222,   -38.017500,    16.836111,   -34.293333),  \
  (   16.836111,   -34.293333,    16.598056,   -28.216111),  \
  (   16.598056,   -28.216111,    16.490000,   -26.431944),  \
  (   16.490000,   -26.431944,    16.353056,   -25.592778),  \
  (   16.353056,   -25.592778,    16.005556,   -22.621667),  \
  (   16.005556,   -22.621667,    15.980833,   -26.114167),  \
  (   16.005556,   -22.621667,    16.090556,   -19.805556),  \
# Scl
  (    0.976667,   -29.357500,    23.815556,   -28.130278),  \
  (   23.815556,   -28.130278,    23.313611,   -32.531944),  \
  (   23.313611,   -32.531944,    23.549444,   -37.818333),  \
# Sct
  (   18.786389,    -4.747778,    18.586667,    -8.244167),  \
  (   18.586667,    -8.244167,    18.486667,   -14.565833),  \
# Ser
  (   15.854444,    20.977778,    15.812222,    18.141667),  \
  (   15.812222,    18.141667,    15.940833,    15.661667),  \
  (   15.812222,    18.141667,    15.692500,    19.670278),  \
  (   15.812222,    18.141667,    15.769722,    15.421944),  \
  (   15.769722,    15.421944,    15.580000,    10.539167),  \
  (   15.580000,    10.539167,    15.737778,     6.425556),  \
  (   15.737778,     6.425556,    15.846944,     4.477778),  \
  (   15.846944,     4.477778,    15.838333,     2.196389),  \
  (   15.838333,     2.196389,    15.826944,    -3.430278),  \
  (   15.826944,    -3.430278,    16.239167,    -3.694444),  \
  (   17.173056,   -15.724722,    17.347222,   -12.846944),  \
  (   17.347222,   -12.846944,    17.626389,   -15.398611),  \
  (   17.626389,   -15.398611,    17.690278,   -12.875278),  \
  (   17.690278,   -12.875278,    17.983889,    -9.773611),  \
  (   17.983889,    -9.773611,    18.355278,    -2.898889),  \
  (   18.355278,    -2.898889,    18.936944,     4.203611),  \
# Sex
  (    9.875000,    -8.105000,    10.491389,    -2.739167),  \
  (   10.491389,    -2.739167,    10.505000,    -0.636944),  \
  (   10.505000,    -0.636944,    10.132222,    -0.371667),  \
  (   10.132222,    -0.371667,     9.875000,    -8.105000),  \
# Tau
  (    5.438333,    28.607500,     4.704167,    22.956944),  \
  (    4.704167,    22.956944,     4.476944,    19.180278),  \
  (    4.476944,    19.180278,     4.424722,    17.928056),  \
  (    4.424722,    17.928056,     4.382222,    17.542500),  \
  (    4.382222,    17.542500,     4.330000,    15.627500),  \
  (    4.330000,    15.627500,     4.477778,    15.870833),  \
  (    4.477778,    15.870833,     4.598611,    16.509167),  \
  (    4.598611,    16.509167,     5.627500,    21.142500),  \
  (    4.330000,    15.627500,     4.011389,    12.490278),  \
  (    4.011389,    12.490278,     3.452778,     9.732778),  \
  (    3.452778,     9.732778,     3.413611,     9.028889),  \
# Tel
  (   18.480556,   -49.070833,    18.449444,   -45.968333),  \
  (   18.449444,   -45.968333,    18.187222,   -45.954444),  \
# Tri
  (    1.884722,    29.578889,     2.288611,    33.847222),  \
  (    2.288611,    33.847222,     2.159167,    34.987222),  \
  (    2.159167,    34.987222,     1.884722,    29.578889),  \
# Tra
  (   15.919167,   -63.430556,    15.315278,   -68.679444),  \
  (   15.315278,   -68.679444,    16.811111,   -69.027778),  \
  (   16.811111,   -69.027778,    15.919167,   -63.430556),  \
# Tuc
  (    0.525833,   -62.958056,    23.290556,   -58.235833),  \
  (   23.290556,   -58.235833,    22.308333,   -60.259722),  \
  (   22.308333,   -60.259722,    22.455556,   -64.966389),  \
  (   22.455556,   -64.966389,     0.334444,   -64.874722),  \
  (    0.334444,   -64.874722,     0.525833,   -62.958056),  \
# Uma
  (   13.792222,    49.313333,    13.398889,    54.925278),  \
  (   13.398889,    54.925278,    12.257222,    57.032500),  \
  (   12.257222,    57.032500,    11.897222,    53.694722),  \
  (   11.897222,    53.694722,    11.767500,    47.779444),  \
  (   11.767500,    47.779444,    11.308056,    33.094167),  \
  (   11.308056,    33.094167,    11.303056,    31.529167),  \
  (   11.767500,    47.779444,    11.161111,    44.498611),  \
  (   11.161111,    44.498611,    10.372222,    41.499444),  \
  (   12.257222,    57.032500,    11.062222,    61.750833),  \
  (   11.062222,    61.750833,     9.525556,    63.061944),  \
  (    9.525556,    63.061944,     8.504444,    60.718056),  \
  (    9.525556,    63.061944,     9.849722,    59.038611),  \
  (    9.849722,    59.038611,     9.868333,    54.064444),  \
  (    9.868333,    54.064444,     9.547500,    51.677222),  \
  (    9.547500,    51.677222,     8.986667,    48.041667),  \
  (   11.062222,    61.750833,    11.030833,    56.382500),  \
  (   11.030833,    56.382500,    11.897222,    53.694722),  \
# Umi
  (    2.530278,    89.264167,    17.536944,    86.586389),  \
  (   17.536944,    86.586389,    16.766111,    82.037222),  \
  (   16.766111,    82.037222,    15.734444,    77.794444),  \
  (   15.734444,    77.794444,    16.291667,    75.755278),  \
  (   16.291667,    75.755278,    15.345556,    71.834167),  \
  (   15.345556,    71.834167,    14.845000,    74.155556),  \
  (   14.845000,    74.155556,    15.734444,    77.794444),  \
# Vel
  (   10.779444,   -49.420000,     9.947778,   -54.567778),  \
  (    9.947778,   -54.567778,     9.368611,   -55.010833),  \
  (    9.368611,   -55.010833,     8.745000,   -54.708333),  \
  (    8.745000,   -54.708333,     8.158889,   -47.336667),  \
  (    8.158889,   -47.336667,     9.133333,   -43.432500),  \
  (    9.133333,   -43.432500,     9.511667,   -40.466667),  \
  (    9.133333,   -43.432500,     9.368611,   -55.010833),  \
# Vir
  (   13.578333,    -0.595833,    14.027500,     1.544444),  \
  (   14.027500,     1.544444,    14.770833,     1.892778),  \
  (   14.770833,     1.892778,    14.717778,    -5.658333),  \
  (   14.717778,    -5.658333,    14.266944,    -6.000556),  \
  (   14.266944,    -6.000556,    13.420000,   -11.161389),  \
  (   13.420000,   -11.161389,    12.694444,    -1.449444),  \
  (   12.694444,    -1.449444,    12.331667,    -0.666944),  \
  (   12.331667,    -0.666944,    11.845000,     1.764722),  \
  (   12.694444,    -1.449444,    12.926667,     3.397500),  \
  (   12.926667,     3.397500,    13.036389,    10.959167),  \
# Vol
  (    9.040833,   -66.396111,     8.428889,   -66.136944),  \
  (    8.428889,   -66.136944,     8.132222,   -68.617222),  \
  (    8.132222,   -68.617222,     7.696944,   -72.606111),  \
  (    7.696944,   -72.606111,     7.145833,   -70.498889),  \
  (    7.145833,   -70.498889,     7.280556,   -67.957222),  \
  (    7.280556,   -67.957222,     8.428889,   -66.136944),  \
# Vul
  (   19.891111,    24.079722,    19.478333,    24.665000),  \
  (   19.478333,    24.665000,    19.270278,    21.390278),  \
]


# ----------------------------------------------------------------------

# Because Python's trig is in radians and I need answers in degrees,
# I often need to convert between radians and degrees.  These two
# functions are for doing that.

def dtor(a):
  """ degrees to radians
  """
  return a * pi / 180.0

def rtod(r):
  """ radians to degrees
  """
  return r * 180.0 / pi


# This function converts a decimal time to hours, minutes and seconds
# format and returns a time object.

def floattotime(f):
  """ convert h.hhhhh to hh:mm:ss
  """
  h = int(f)
  mm = (f - h) * 60.0
  m = int(mm)
  s = (mm - m) * 60.0
  s = int(s)
  t = time(h, m, s)
  return t


# This function converts a decimal angle to degrees, minutes and seconds
# format and returns a string "ddd mm ss".

def floattoangle(f):
  """ convert d.ddddd to ddd mm ss
  """
  h = int(f)
  mm = (f - h) * 60.0
  m = int(mm)
  s = (mm - m) * 60.0
  s = int(s)
  return '%(degree)03dd%(minute)02dm%(second)02ds' % \
         { 'degree' : h, 'minute' : abs(m), 'second': abs(s)}

def angletofloat(s):
  """ convert xxxdyymzzs to ddd.dddddd
     (will accept any character as separator but you must specify degrees,
      minutes and seconds.)
  """
  d = 0.0
  i = 0
  while (i < 4):
    c = s[i]
    c = c[0]
    if (c.isdigit()):
      i = i + 1
    else:
      break
  t = s[0:i]
  d = float(t)
  i = i + 1
  t = s[i:]
  s = t
  i = 0
  while (i < 3):
    c = s[i]
    c = c[0]
    if (c.isdigit()):
      i = i + 1
    else:
      break
  t = s[0:i]
  d = d + float(t)/60.0    
  i = i + 1
  t = s[i:]
  s = t
  i = 0
  while (i < 3):
    c = s[i]
    c = c[0]
    if (c.isdigit()):
      i = i + 1
    else:
      break
  t = s[0:i]
  d = d + float(t)/3600.0    
  return d

def jtime(dd):
  """ convert utc date/time to julian date
  """
  y = dd.year
  m = dd.month
  d = dd.day + dd.hour / 24.0 + dd.minute / 1440.0 + dd.second / 86400.0
  if (m < 3):
    m = m + 12
    y = y - 1
  a = int(y / 100.0)
  b = 2 - a + int(a / 4)
  c = int(365.25 * y)
  cd = int(30.6001 * (m + 1))
  t = b + c + cd + d + 1720994.5
  return t


def gst(d):
  """ convert utc date/time to gst
  """
  d1 = datetime(d.year, d.month, d.day, 0, 0, 0)
  t1 = d.time()
  j = jtime(d1)
  s = j - 2451545.0
  t = s / 36525.0
  t0 = 6.697374558 + 2400.051336 * t + 0.000025862 * t * t
  while (t0 < 0.0):
    t0 = t0 + 24.0
  while (t0 > 24.0):
    t0 = t0 - 24.0
  ut = t1.hour + t1.minute / 60.0 + t1.second / 3600.0
  ut = ut * 1.002737909
  t0 = t0 + ut
  while (t0 < 0.0):
    t0 = t0 + 24.0
  while (t0 > 24.0):
    t0 = t0 - 24.0
  return t0


def lst(g):
  """ convert gst to lst
  """
  l = longitude / 15.0
  lst = g + l
  while (lst < 0.0):
    lst = lst + 24.0
  while (lst > 24.0):
    lst = lst - 24.0
  return lst


def hrangl(ra, ut):
  """ convert ra to hour angle
  """
  g = gst(ut)
  l = lst(g)
  h = l - ra
  while (h < 0.0):
    h = h + 24.0
  while (h > 24.0):
    h = h - 24.0
  return h


def epochpolartonow(polar, ut):
  """ adjust J2000 polar value for precession
  ---> may be untrustworthy
  """
  dec = polar[1]
  ra = polar[0]
# this method is an approximation which fails when
# the star is near the celestial pole.  So we return
# the epoch's ra -- a better answer than what the
# algorithm would produce
  if (dec > 88.0):
     return (ra, dec)
  if (dec < -88.0):
     return (ra, dec)
# dec is in tolerance.
  n = (ut.year - 2000.0) + (ut.month - 1.0) / \
      12.0 + 15.0 / 360.0
  ra = ra * 15.0
  ra1 = ra + ((3.0742 + \
        1.33589 * sin(dtor(ra)) * \
        tan(dtor(dec))) / 3600.0)  * n
  dec1 = dec + (20.0383 * cos(dtor(ra))) / 3600.0 * n
  return (ra1 / 15.0, dec1)


def polartoazalt(polar, ut):
  """ convert ra, dec, ut to az, alt
  """
  ra = polar[0]
  dec = polar[1]
  h = hrangl(ra, ut)
  h = h * 15.0
  a = asin(sin(dtor(dec)) * sin(dtor(latitude)) + cos(dtor(dec)) *
           cos(dtor(latitude)) * cos(dtor(h)))
  az = acos((sin(dtor(dec)) - sin(dtor(latitude)) * sin(a)) /
            (cos(dtor(latitude)) * cos(a)))
  sh = sin(dtor(h))
  if (sh > 0.0):
    az = 2.0 * pi - az
  return (rtod(az), rtod(a))


def eccentric_anomaly(M, e):
# solve M = E - (57.29578 * e) * sin(E) for E
  dE = .05
  estar = 180.0 * e / pi
  
# Iterate dM = M - En - estar * sin(En); dE = dM / (1 - e * cos(En)); En = En + dE
# until abs(dE) <= 0.001
# note that M and estar are in degrees, as is E and dE so make the appropriate
# conversion to radians before doing trig.

  En = M
  while (abs(dE) > .001):
    dM = M - (En - estar * sin(dtor(En)))
    dE = dM / (1 - e * cos(dtor(En)))
    En = En + dE
  return En

# -----------------------------------------------------------------------
#
# These controls and control state-variables must be "global" or we can't
# retrieve their values:
#
menubar1 = gtk.HBox(False, 5)
menubar2 = gtk.HBox(False, 5)
menubar3 = gtk.HBox(False, 5)
# controls on menubar1:
button1 = gtk.ToggleButton("Night Vision")
button2 = gtk.ToggleButton("Invert Display")
button3 = gtk.ToggleButton("Flip L/R")
button4 = gtk.ToggleButton("Draw Constellations")
label6 = gtk.Label("Mag:")
rb7 = gtk.RadioButton(None, "0")
rb8 = gtk.RadioButton(rb7, "1")
rb9 = gtk.RadioButton(rb7, "2")
rb10 = gtk.RadioButton(rb7, "3")
rb11 = gtk.RadioButton(rb7, "4")
rb12 = gtk.RadioButton(rb7, "5")
rb13 = gtk.RadioButton(rb7, "6")
# controls on menubar2:
label1 = gtk.Label("Longitude:")
entry1 = gtk.Entry()
entry1.set_width_chars(12)
rb1 = gtk.RadioButton(None, "E")
rb2 = gtk.RadioButton(rb1, "W")
label2 = gtk.Label("Latitude:")
entry2 = gtk.Entry()
entry2.set_width_chars(12)
rb3 = gtk.RadioButton(None, "N")
rb4 = gtk.RadioButton(rb3, "S")
button5 = gtk.Button("Apply new location")
# controls on menubar3:
rb5 = gtk.RadioButton(None, "Now")
rb6 = gtk.RadioButton(rb5, "Specify")
label4 = gtk.Label("Time:")
entry3 = gtk.Entry()
entry3.set_width_chars(16)
label5 = gtk.Label("Offset:")
entry4 = gtk.Entry()
entry4.set_width_chars(7)
button6 = gtk.Button("Apply new time")

# -----------------------------------------------------------------------

def initialize_controls():
  button4.clicked()
  entry2.set_text(floattoangle(abs(latitude)))
  if (latitude < 0.0):
    rb4.clicked()
  else:
    rb3.clicked()
  entry1.set_text(floattoangle(abs(longitude)))
  if (longitude < 0.0):
    rb2.clicked()
  else:
    rb1.clicked()
  rb5.clicked()
  entry3.set_text("")
  set_time_and_UTC_offset()
  rb11.clicked()

  
def parse_zone_offset(s):
  bneg = False
  oh = 0
  om = 0
  i = 0
  if (s[0] == '-'):
    bneg = True
    i = 1
  elif (s[0] == '+'):
    i = 1
  j = i
  while (s[j].isdigit()):
    j = j + 1
  if (j == i):
    return (0, 0)
  oh = int(s[i:j])
  i = j
  if (s[i] != ':'):
    return (0, 0)
  i = i + 1
  om = int(s[i:])
  if (bneg):
    oh = -oh
    om = -om
  return (oh, om)

def parse_timestamp(s):
  if ((s[4] != '/') or (s[7] != '/') or (s[10] != ',') or (s[13] != ':')):
    return (2000, 1, 1, 0, 0)
  Y = int(s[0:4])
  M = int(s[5:7])
  D = int(s[8:10])
  h = int(s[11:13])
  m = int(s[14:])
  return (Y, M, D, h, m)

def get_time_and_UTC_offset():
  class TZ(tzinfo):
    """Fixed offset in minutes east from UTC."""

    def __init__(self, offset, name):
        self.__offset = timedelta(minutes = offset)
        self.__name = name

    def utcoffset(self, dt):
        return self.__offset

    def tzname(self, dt):
        return self.__name

    def dst(self, dt):
        return timedelta(0)

# Read the timestamp in entry3 and the UTC offset in entry4 and return the
# GMT time as a datetime object.

  (sy, sM, sd, sh, sm) = parse_timestamp(entry3.get_text())
  (oh, om) = parse_zone_offset(entry4.get_text())
  tzo = oh * 60 + om
  tz = TZ(tzo, "")
  lt = datetime(sy, sM, sd, sh, sm, 0, 0, tz)
  gt = lt - tz.utcoffset(0)
  return gt

def set_time_and_UTC_offset():
      
# Using the local time and the GMT time, set the text in entry3 and entry4 to
# the local time and the zone offset, respectively

    gt = datetime.utcnow()
    lt = datetime.fromtimestamp(systime())
    dt = lt - gt
    lts = lt.strftime("%Y/%m/%d,%H:%M")
    entry3.set_text(lts)
    dth = dt.days * 24 + int(dt.seconds / 3600)
    dtm = (dt.seconds / 60) % 60
    utos = "%d:%02d" % (dth, dtm)
    entry4.set_text(utos)

# -----------------------------------------------------------------------

try:
  class StarChart(activity.Activity):
    def __init__(self, handle):
      activity.Activity.__init__(self, handle)

      self.set_title("Star Chart")
      toolbox = activity.ActivityToolbox(self)
      self.set_toolbox(toolbox)
      toolbox.show()
      widget = self.get_children()
      things = widget[0].get_children()
      widget[0].remove(things[1])

# Fill the menu bars

      menubar1.pack_start(button1, False, False, 5)
      menubar1.pack_start(button2, False, False, 5)
      menubar1.pack_start(button3, False, False, 5)
      menubar1.pack_start(button4, False, False, 5)
      menubar1.pack_start(label6, False, False, 5)
      menubar1.pack_start(rb7, False, False, 1)
      menubar1.pack_start(rb8, False, False, 1)
      menubar1.pack_start(rb9, False, False, 1)
      menubar1.pack_start(rb10, False, False, 1)
      menubar1.pack_start(rb11, False, False, 1)
      menubar1.pack_start(rb12, False, False, 1)
      menubar1.pack_start(rb13, False, False, 1)
      menubar2.pack_start(label1, False, False, 5)
      menubar2.pack_start(entry1, False, False, 5)
      menubar2.pack_start(rb1, False, False, 1)
      menubar2.pack_start(rb2, False, False, 1)
      menubar2.pack_start(label2, False, False, 5)
      menubar2.pack_start(entry2, False, False, 5)
      menubar2.pack_start(rb3, False, False, 1)
      menubar2.pack_start(rb4, False, False, 1)
      menubar2.pack_end(button5, False, False, 5)
      menubar3.pack_start(rb5, False, False, 1)
      menubar3.pack_start(rb6, False, False, 1)
      menubar3.pack_start(label4, False, False, 5)
      menubar3.pack_start(entry3, False, False, 5)
      menubar3.pack_start(label5, False, False, 5)
      menubar3.pack_start(entry4, False, False, 5)
      menubar3.pack_end(button6, False, False, 5)

# Fill the user area

      widget[0].pack_start(menubar1, False, False, 2)
      widget[0].pack_start(menubar2, False, False, 2)
      widget[0].pack_start(menubar3, False, False, 2)
      chart = ChartDisplay()
      widget[0].pack_end(chart, True, True, 2)

# Connect the events

      button1.connect("toggled", chart.callback, "night vision")
      button2.connect("toggled", chart.callback, "invert display")
      button3.connect("toggled", chart.callback, "flip horizontally")
      button4.connect("toggled", chart.callback, "draw constellations")
      button5.connect("clicked", chart.callback, "location change")
      rb1.connect("clicked", chart.callback, "rb1 clicked")
      rb2.connect("clicked", chart.callback, "rb2 clicked")
      rb3.connect("clicked", chart.callback, "rb3 clicked")
      rb4.connect("clicked", chart.callback, "rb4 clicked")
      rb5.connect("clicked", chart.callback, "rb5 clicked")
      rb6.connect("clicked", chart.callback, "rb6 clicked")
      rb7.connect("clicked", chart.callback, "rb7 clicked")
      rb8.connect("clicked", chart.callback, "rb8 clicked")
      rb9.connect("clicked", chart.callback, "rb9 clicked")
      rb10.connect("clicked", chart.callback, "rb10 clicked")
      rb11.connect("clicked", chart.callback, "rb11 clicked")
      rb12.connect("clicked", chart.callback, "rb12 clicked")
      rb13.connect("clicked", chart.callback, "rb13 clicked")
      button6.connect("clicked", chart.callback, "time change")
      chart.connect("expose_event", chart.area_expose_cb)

      initialize_controls()
      self.show_all()
except: pass

# -------------------------------------------------------------------------------


class ChartDisplay(gtk.DrawingArea):
  def __init__(self):
    super(ChartDisplay, self).__init__()
    self.nightvision = False
    self.drawconstellations = False
    self.fliphorizontally = False
    self.invertdisplay = False;
    self.colors = {}
    self.rb1Clicked = True
    self.rb2Clicked = False
    self.rb3Clicked = True
    self.rb4Clicked = False
    self.rb5Clicked = True
    self.rb6Clicked = False
    self.limiting_mag = 4.0

  def area_expose_cb(self, area, event):

# Determine the area we can use for drawing upon.

    rect = self.get_allocation()
    self.screensize = (rect.width, rect.height)
    self.margin = 40
    self.diameter = min(self.screensize[0], self.screensize[1]) - 2 * self.margin
    self.xoffset = (self.screensize[0] - self.diameter) / 2 - self.margin
    self.yoffset = (self.screensize[1] - self.diameter) / 2 - self.margin

# Establish color selections (need only do this once)

    self.gc = self.style.fg_gc[gtk.STATE_NORMAL]
    if (len(self.colors) == 0):
      self.colormap = self.gc.get_colormap()
      self.colors[0] = self.colormap.alloc_color('white')
      self.colors[1] = self.colormap.alloc_color('black')
      self.colors[2] = self.colormap.alloc_color('red')
      self.colors[3] = self.colormap.alloc_color('gray')
    self.cleararea()

# create timer to re-plot at a rate of once a minute.

    gobject.timeout_add(60000, self.timer1_cb)

# do initial plot

    self.plotchart()
    return True

  def timer1_cb(self):
    self.plotchart()
    return True
  
  def azalttoxy(self, polar):
    az = dtor(polar[0])
    alt = polar[1]

# radius is proportional to 90-alt

    r = self.diameter / 2.0 - alt * (self.diameter / 2.0 /90.0)

# convert r and az to x and y
# flip the chart so east is on the left by default.
# (Insert code here to flip the chart horizontally from user preference.)
# When flipped, the equation becomes x = int(diameter / 2.0 + r * sin(az)).

    if (self.fliphorizontally):
      x = int(self.diameter / 2.0 + r * sin(az))
    else:
      x = int(self.diameter / 2.0 - r * sin(az))
    y = int(self.diameter / 2.0 - r * cos(az))
    return (x,y)


    
  def plotchart(self):

# Erase prior plot

    if (self.invertdisplay):
      if (self.nightvision):
        self.gc.set_foreground(self.colors[2])
      else:
        self.gc.set_foreground(self.colors[0])
    else:
      self.gc.set_foreground(self.colors[1])
    self.window.draw_arc(self.gc,
                              True,
                              self.xoffset + self.margin - 2,
                              self.yoffset + self.margin - 2,
                              self.diameter + 4,
                              self.diameter + 4,
                              0,
                              360 * 64)

# Plot sky circle

    if (not self.invertdisplay):
      if (self.nightvision):
        self.gc.set_foreground(self.colors[2])
      else:
        self.gc.set_foreground(self.colors[0])
    else:
      self.gc.set_foreground(self.colors[1])
    self.window.draw_arc(self.gc,
                              False,
                              self.xoffset + self.margin - 2,
                              self.yoffset + self.margin - 2,
                              self.diameter + 4,
                              self.diameter + 4,
                              0,
                              360 * 64)
    if (not self.invertdisplay):
      if (self.nightvision):
        self.gc.set_foreground(self.colors[2])
      else:
        self.gc.set_foreground(self.colors[0])
    else:
      self.gc.set_foreground(self.colors[1])

# Set the time of plotting (now).

    if (self.rb5Clicked):
      now = datetime.utcnow()
      set_time_and_UTC_offset()
    else:
      now = get_time_and_UTC_offset()

# Plot the stars.

    for name, (ra, dec, mag) in star_chart.iteritems():
      if (mag <= self.limiting_mag):
# convert the ra and dec from the J2000 epoch to the plot time
        polar = epochpolartonow((ra, dec), now)
# convert the equatorial coordinates to altitude and azimuth
        azalt = polartoazalt(polar, now)
# plot any object that is more than 1 degree above the horizon
        if (azalt[1] >= 0.0175):
          starsize = 2 + int(7.0 - mag)
          (px, py) = self.azalttoxy(azalt)
          px = px + self.margin - 2 + self.xoffset - starsize / 2
          py = py + self.margin - 2 + self.yoffset - starsize / 2
          self.window.draw_arc(self.gc, True,
                 px,
                 py,
                 starsize,
                 starsize,
                 0,
                 360*64)

# Plot the constellation figures.  This is essentially the same process as for
# plotting a star but we have to figure out the alt/az coordinates for both ends
# of the line segment.

    if (self.drawconstellations):
      if (not self.invertdisplay):
        if (self.nightvision):
          self.gc.set_foreground(self.colors[2])
        else:
          self.gc.set_foreground(self.colors[0])
      else:
        self.gc.set_foreground(self.colors[1])
      for i in range(len(figures)):
        (ra1, dec1, ra2, dec2) = figures[i]
        polar1 = epochpolartonow((ra1, dec1), now)
        azalt1 = polartoazalt(polar1, now)
        if (azalt1[1] >=  0.0175):
          (px1, py1) = self.azalttoxy(azalt1)
          px1 = px1 + self.margin - 2 + self.xoffset
          py1 = py1 + self.margin - 2 + self.yoffset
          polar2 = epochpolartonow((ra2, dec2), now)
          azalt2 = polartoazalt(polar2, now)
          if (azalt2[1] >=  0.0175):
            (px2, py2) = self.azalttoxy(azalt2)
            px2 = px2 + self.margin - 2 + self.xoffset
            py2 = py2 + self.margin - 2 + self.yoffset
            self.window.draw_line(self.gc, px1, py1, px2, py2)

# Plot the planets, the moon and the sun.

# We need to adjust the Keplerian data by the number of centuries since the epoch.
# Mostly, this causes the planets to revolve around the sun at the rate of their
# orbital period (N in the following computations), but the orbits themselves will
# also change over time.
# FIXME: for now, we only worry about orbital motion, not additionally orbital mutation.

    T = (jtime(now) - 2451545.0) / 36525.0

# Calculate the earth's heliocentric radius and longitude coordinates so we
# can figure the geocentric ecliptic coordinates of the other planets.
# (I'm pretty sure that this is giving the right answer.)
    (name, wbar, e, a, I, O, L0, dL) = planets[2]
    N = dL * T
    while (N >= 360.0):
      N = N - 360.0
    while (N < 0.0):
      N = N + 360.0
# FIXME: Should adjust the orbit's inclination and orientation
#    I = I0 + dI * T
#    wbar = wbar0 + dwbar * T
#    O = O0 + dO * T
    M = N + L0 - wbar
    while (M >= 360.0):
      M = M - 360.0
    while (M < 0.0):
      M = M + 360.0
    Le = N + 2 * rtod(e) * sin(dtor(M)) + L0
    while (Le >= 360.0):
      Le = Le - 360.0
    while (Le < 0.0):
      Le = Le + 360.0
    v = Le - wbar
    Re = a * (1 - e * e) / (1 + e * cos(dtor(v)))

# now plot the planets.

    for i in range(len(planets)):
      if (i == 2):
        continue
      (name, wbar, e, a, I, O, L0, dL) = planets[i]
      N = dL * T
      while (N >= 360.0):
        N = N - 360.0
      while (N < 0.0):
        N = N + 360.0
# FIXME:  For Mercury, especially, dI, dwbar and dO are large enough to matter.
#      I = I0 + dI * T
#      wbar = wbar0 + dwbar * T
#      O = O0 + dO * T
# compute the mean anomaly
      M = N + L0 - wbar
      while (M >= 360.0):
        M = M - 360.0
      while (M < 0.0):
        M = M + 360.0

# FIXME: 
# Rather than solve Keppler's equation (M = E - 180/pi * e * sin(E)) for E, we
# will use the approximation E ~ M and calculate the heliocentric longitude
# using the mean anomaly instead of the eccentric anomaly.  This approximation
# is pretty close except for Mercury and Pluto which have values of e high
# enough to make a difference.

# compute the heliocentric longitude
      l = N + 2 * rtod(e) * sin(dtor(M)) + L0
      while (l >= 360.0):
        l = l - 360.0
      while (l < 0.0):
        l = l + 360.0
# now calculate the actual anomaly
      v = l - wbar
# find the planet's radial distance
      r = a * (1 - e * e) / (1 + e * cos(dtor(v)))
# calculate the heliocentric latitude
      psi = rtod(asin(sin(dtor(l - O)) * sin(dtor(I))))
# project to the ecliptic
      y = sin(dtor(l - O)) * cos(dtor(I))
      x = cos(dtor(l - O))
      k = rtod(atan2(y, x))
      lprime = k + O
      while (lprime >= 360.0):
        lprime = lprime - 360.0
      while (lprime < 0.0):
        lprime = lprime + 360.0
      rprime = r * cos(dtor(psi))
# Using the coordinates we already calculated for the current position of the
# earth, convert the above coordinates to geocentric latitude and longitude
      if (i < 2):
# for inner planets, use this equation to get longitude:
        y = rprime * sin(dtor(Le - lprime))
        x = Re - rprime * cos(dtor(Le - lprime))
        k = rtod(atan2(y, x))
        lam = 180.0 + Le + k 
      else:
# for outer planets, use this equation to get longitude:
        y = Re * sin(dtor(lprime - Le))
        x = rprime - Re * cos(dtor(lprime - Le))
        k = rtod(atan2(y, x))
        lam = k + lprime
      while (lam >= 360.0):
        lam = lam - 360.0
      while (lam < 0.0):
        lam = lam + 360.0
# all planets use the same equation for ecliptic latitude (and this atan has no quadrant ambiguity):
      y = rprime * tan(dtor(psi)) * sin(dtor(lam - lprime))
      x = Re * sin(dtor(lprime - Le))
      beta = rtod(atan(y/x))
# convert lam and beta to RA and DEC
      y = sin(dtor(lam)) * cos(eps) - tan(dtor(beta)) * sin(eps)
      x = cos(dtor(lam))
      k = rtod(atan2(y, x))
      ra = k / 15.0
      while (ra < 0.0):
        ra = ra + 24.0
      dec = rtod(asin(sin(dtor(beta)) * cos(eps) + cos(dtor(beta)) * sin(eps) * sin(dtor(lam))))
# convert to azalt
      azalt = polartoazalt((ra, dec), now)
# convert to x,y and plot if the planet is above the horizon
      if (azalt[1] >= 0.0175):
        (px, py) = self.azalttoxy(azalt)
        px = px + self.margin - 2 + self.xoffset
        py = py + self.margin - 2 + self.yoffset
        self.plot_planetary_symbol(i, px, py)

# Plot the sun.  This is virtually the same as for a planet, but we can simplify
# some computations because the sun is by definition on the ecliptic.

    (name, wbar, e, a, I, O, L0, dL) = sun
    N = dL * T
    while (N >= 360.0):
      N = N - 360.0
    while (N < 0.0):
      N = N + 360.0    
    M = N + L0 - wbar
    while (M >= 360.0):
      M = M - 360.0
    while (M < 0.0):
      M = M + 360.0
    v = M + 2 * rtod(e) * sin(dtor(M))
    while (v >= 360.0):
      v = v - 360.0
    while (lam < 0.0):
      v = v + 360.0
    lam = v + wbar
    while (lam >= 360.0):
      lam = lam - 360.0
    while (lam < 0.0):
      lam = lam + 360.0
    y = sin(dtor(lam)) * cos(eps)
    x = cos(dtor(lam))
    k = rtod(atan2(y, x))
    ra = k / 15.0
    while (ra < 0.0):
      ra = ra + 24.0
# because beta is (by definition) 0, calculating dec is far simpler:
    dec = rtod(asin(sin(sin(eps) * sin(dtor(lam)))))
    azalt = polartoazalt((ra, dec), now)
    if (azalt[1] >= 0.0175):
      (px, py) = self.azalttoxy(azalt)
      px = px + self.margin - 2 + self.xoffset
      py = py + self.margin - 2 + self.yoffset
      self.plot_planetary_symbol(7, px, py)

# TODO: plot moon
# FIXME:  it's broken.

    (L0, P0, N0, I, e, a, phi0, tau) = moon
    D = jtime(now) - float(tau)
    print tau
    print jtime(now)
    print D
    N = 360.0 / 365.242191 * D
    while (N >= 360.0):
      N = N - 360.0
    while (N < 0.0):
      N = N + 360.0
    print N
    M = N + L0 - P0
    while (M >= 360.0):
      M = M - 360.0
    while (M < 0.0):
      M = M + 360.0
    Ec = 2 * rtod(e) * sin(dtor(M))
    lam = Ec + L0
    while (lam >= 360.0):
      lam = lam - 360.0
    while (lam < 0.0):
      lam = lam + 360.0
    l = 13.176396 * D + L0               
    while (l >= 360.0):
      l = l - 360.0
    while (l < 0.0):
      l = l + 360.0
    Mm = l - 0.1114041 * D - P0
    while (Mm >= 360.0):
      Mm = Mm - 360.0
    while (Mm < 0.0):
      Mm = Mm + 360.0
    N = N0 - 0.0529539 * D
    while (N >= 360.0):
      N = N - 360.0
    while (N < 0.0):
      N = N + 360.0
    Ev = 1.2739 * sin(dtor(2 * (1 - lam) - Mm))
    Ae = 0.1858 * sin(dtor(M))
    A3 = 0.37 * sin(dtor(M))
    Mprime = Mm + Ev - Ae - A3
    Ec = 6.2886 * sin(dtor(Mprime))
    A4 = 0.214 * sin (dtor(2 * Mprime))
    lprime = l + Ev  + Ec - Ae + A4
    V = 0.6583 * sin(dtor(2 * (lprime - lam)))
    lon = lprime + V
    Nprime = N - 0.16 * sin(dtor(M))
    y = sin(dtor(lon - Nprime)) * cos(dtor(I))
    x = cos(dtor(lon - Nprime))
    k = rtod(atan2(y, x))
    lamM = Nprime + k
    while (lamM >= 360.0):
      lamM = lamM - 360.0
    while (lamM < 0.0):
      lamM = lamM + 360.0
    betM = rtod(asin(sin(dtor(lon - Nprime)) * sin(dtor(I))))

# FIXME: We aren't accounting for parallax.


    y = sin(dtor(lamM)) * cos(eps) - tan(dtor(betM)) * sin(eps)
    x = cos(dtor(lamM))
    k = rtod(atan2(y, x))
    ra = k / 15.0
    while (ra < 0.0):
      ra = ra + 24.0
    while (ra > 24.0):
      ra = ra - 24.0
    dec = rtod(asin(sin(dtor(betM)) * cos(eps) + cos(dtor(betM)) * sin(eps) * sin(dtor(lamM))))
# convert to azalt
    azalt = polartoazalt((ra, dec), now)
    if (azalt[1] >= 0.0175):
      (px, py) = self.azalttoxy(azalt)
      px = px + self.margin - 2 + self.xoffset
      py = py + self.margin - 2 + self.yoffset
      self.plot_planetary_symbol(2, px, py)
    return True


  def callback(self, widget, data=None):
    global longitude
    global latitude
    if (data == "night vision"):
      self.nightvision = not self.nightvision
      self.cleararea()
      self.plotchart()
    if (data == "invert display"):
      self.invertdisplay = not self.invertdisplay
      self.cleararea()
      self.plotchart()
    if (data == "draw constellations"):
      self.drawconstellations = not self.drawconstellations
      self.cleararea()
      self.plotchart()
    if (data == "flip horizontally"):
      self.fliphorizontally = not self.fliphorizontally
      self.cleararea()
      self.plotchart()
    if (data == "location change"):
      s = entry1.get_text()
      lon = angletofloat(s)
      if (lon > 180.0):
# FIXME: invalid entry -- show error on status line and restore text
        print "The longitude value is invalid."
        entry1.set_text(floattoangle(abs(longitude)))
        if (longitude < 0.0):
          rb2.clicked()
        else:
          rb1.clicked()
      else:
        longitude = lon
        if (self.rb2Clicked):
          longitude = -longitude
      s = entry2.get_text()
      lat = angletofloat(s)
      if (lat > 90.0):
# FIXME: invalid entry -- show error on status line and restore text
        print "The latitude value is invalid."
        entry2.set_text(floattoangle(abs(latitude)))
        if (latitude < 0.0):
          rb4.clicked()
        else:
          rb3.clicked()
      else:
        latitude = lat
        if (self.rb4Clicked):
          latitude = -latitude
      self.cleararea()
      self.plotchart()
    if (data == "rb1 clicked"):
      self.rb1Clicked = True
      self.rb2Clicked = False
    if (data == "rb2 clicked"):
      self.rb2Clicked = True
      self.rb1Clicked = False
    if (data == "rb3 clicked"):
      self.rb3Clicked = True
      self.rb4Clicked = False
    if (data == "rb4 clicked"):
      self.rb4Clicked = True
      self.rb3Clicked = False
    if (data == "rb5 clicked"):
      self.rb5Clicked = True
      self.rb6Clicked = False
    if (data == "rb6 clicked"):
      self.rb6Clicked = True
      self.rb5Clicked = False
    if (data == "time change"):
      self.cleararea()
      self.plotchart()
    if (data == "rb7 clicked"):
      self.limiting_mag = 0.0
      self.cleararea()
      self.plotchart()
    if (data == "rb8 clicked"):
      self.limiting_mag = 1.0
      self.cleararea()
      self.plotchart()
    if (data == "rb9 clicked"):
      self.limiting_mag = 2.0
      self.cleararea()
      self.plotchart()
    if (data == "rb10 clicked"):
      self.limiting_mag = 3.0
      self.cleararea()
      self.plotchart()
    if (data == "rb11 clicked"):
      self.limiting_mag = 4.0
      self.cleararea()
      self.plotchart()
    if (data == "rb12 clicked"):
      self.limiting_mag = 5.0
      self.cleararea()
      self.plotchart()
    if (data == "rb13 clicked"):
      self.limiting_mag = 6.0
      self.cleararea()
      self.plotchart()
      
  def cleararea(self):

# FIXME: ensure that the menubar controls always have black text

    label1.queue_draw()
    label2.queue_draw()
    label4.queue_draw()
    label5.queue_draw()
    label6.queue_draw()

# Clear the drawing surface

    if (self.nightvision):
      self.gc.set_foreground(self.colors[1])
    else:
      self.gc.set_foreground(self.colors[3])
    self.window.draw_rectangle(self.gc,
                                    True,
                                    1,
                                    1,
                                    self.screensize[0],
                                    self.screensize[1]);

  def plot_planetary_symbol(self, i, px, py):
# i is planet number (0 = mercury, 1= venus, 2 = moon, 3 = mars, 4 = jupiter, 5 = saturn, 6 = uranus, 7 = sun)
# px,py is the center point of the symbol

    if (i == 0):
# mercury
      self.gc.set_line_attributes(2, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
      self.window.draw_arc(self.gc, False, px-12, py-12, 24, 24, 0, 360*64)
      self.window.draw_arc(self.gc, False, px-5, py-7, 10, 10, 0, 360*64)
      self.window.draw_line(self.gc, px+4, py-9, px+4, py-7)
      self.window.draw_line(self.gc, px-4, py-9, px-4, py-7)
      self.gc.set_line_attributes(1, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
      self.window.draw_line(self.gc, px, py+3, px, py+7)
      self.window.draw_line(self.gc, px-2, py+5, px+2, py+5)
    elif (i == 1):
# venus
      self.gc.set_line_attributes(2, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
      self.window.draw_arc(self.gc, False, px-12, py-12, 24, 24, 0, 360*64)
      self.window.draw_arc(self.gc, False, px-5, py-7, 10, 10, 0, 360*64)
      self.gc.set_line_attributes(1, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
      self.window.draw_line(self.gc, px, py+3, px, py+7)
      self.window.draw_line(self.gc, px-2, py+5, px+2, py+5)
    elif (i == 2):
# TODO: moon
      self.gc.set_line_attributes(2, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
      self.window.draw_arc(self.gc, False, px-12, py-12, 24, 24, 0, 360*64)
      self.window.draw_polygon(self.gc, True, ((px+1, py-11), (px+4, py-11), (px+5, py-10),
                                               (px+6, py-9), (px+7, py-8), (px+8, py-6),
                                               (px+10, py-2), (px+12,py), (px+10, py+2),
                                               (px+8, py+6), (px+7, py+8), (px+6, py+9),
                                               (px+5, py+10), (px+4,py+11), (px+1, py+11),
                                               (px+4, py+4), (px+6, py+2), (px+6, py-2),
                                               (px+4, py-4)))
      self.gc.set_line_attributes(1, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
    elif (i == 3):
# mars
      self.gc.set_line_attributes(2, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
      self.window.draw_arc(self.gc, False, px-12, py-12, 24, 24, 0, 360*64)
      self.window.draw_arc(self.gc, False, px-6, py-4, 10, 10, 0, 360*64)
      self.gc.set_line_attributes(1, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
      self.window.draw_line(self.gc, px+2, py-2, px+6, py-6)
      self.window.draw_line(self.gc, px+3, py-6, px+6, py-6)
      self.window.draw_line(self.gc, px+6, py-6, px+6, py-3)
    elif (i == 4):
# jupiter
      self.gc.set_line_attributes(2, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
      self.window.draw_arc(self.gc, False, px-12, py-12, 24, 24, 0, 360*64)
      self.window.draw_line(self.gc, px-6, py-6, px-4, py-8)
      self.window.draw_line(self.gc, px-4, py-8, px-2, py-8)
      self.window.draw_line(self.gc, px-2, py-8, px+1, py-6)
      self.window.draw_line(self.gc, px+1, py-6, px-5, py+2)
      self.window.draw_line(self.gc, px-5, py+2, px+7, py+2)
      self.window.draw_line(self.gc, px+4, py-8, px+4, py+7)
      self.gc.set_line_attributes(1, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
    elif (i == 5):
# saturn
      self.gc.set_line_attributes(2, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
      self.window.draw_arc(self.gc, False, px-12, py-12, 24, 24, 0, 360*64)
      self.window.draw_line(self.gc, px-6, py-6, px-6, py+5)
      self.window.draw_line(self.gc, px-6, py, px-5, py-1)
      self.window.draw_line(self.gc, px-5, py-1, px-4, py-2)
      self.window.draw_line(self.gc, px-4, py-2, px-1, py-3)
      self.window.draw_line(self.gc, px-1, py-3, px, py-4)
      self.window.draw_line(self.gc, px, py-4, px+1, py+1)
      self.window.draw_line(self.gc, px+1, py+1, px-1, py+4)
      self.window.draw_line(self.gc, px-1, py+4, px, py+5)
      self.window.draw_line(self.gc, px, py+5, px+6, py+4)
      self.gc.set_line_attributes(1, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
    elif (i == 6):
# uranus
      self.gc.set_line_attributes(2, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
      self.window.draw_arc(self.gc, False, px-12, py-12, 24, 24, 0, 360*64)
      self.window.draw_arc(self.gc, False, px-5, py-3, 10, 10, 0, 360*64)
      self.window.draw_arc(self.gc, True, px-2, py, 4, 4, 0, 360*64)
      self.gc.set_line_attributes(1, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
      self.window.draw_line(self.gc, px, py-3, px, py-9)
      self.window.draw_line(self.gc, px-2, py-5, px, py-9)
      self.window.draw_line(self.gc, px+2, py-5, px, py-9)
    else:
# sun
      self.gc.set_line_attributes(2, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)
      self.window.draw_arc(self.gc, False, px-12, py-12, 24, 24, 0, 360*64)
      self.window.draw_arc(self.gc, True, px-2, py-2, 4, 4, 0, 360*64)
      self.gc.set_line_attributes(1, gtk.gdk.LINE_SOLID, gtk.gdk.CAP_BUTT, gtk.gdk.JOIN_MITER)


# -------------------------------------------------------------------------------


# This code lets me debug the application as a stand-alone PyGtk app:

 
class MainChart:
  def __init__(self):
    window = gtk.Window(gtk.WINDOW_TOPLEVEL)
    window.set_title("Star Chart")
    window.connect("destroy", lambda w: gtk.main_quit())
    window.set_size_request(725, 725)
    area = gtk.VBox(False, 5)
    menubar1.pack_start(button1, False, False, 5)
    menubar1.pack_start(button2, False, False, 5)
    menubar1.pack_start(button3, False, False, 5)
    menubar1.pack_start(button4, False, False, 5)
    menubar1.pack_start(label6, False, False, 5)
    menubar1.pack_start(rb7, False, False, 1)
    menubar1.pack_start(rb8, False, False, 1)
    menubar1.pack_start(rb9, False, False, 1)
    menubar1.pack_start(rb10, False, False, 1)
    menubar1.pack_start(rb11, False, False, 1)
    menubar1.pack_start(rb12, False, False, 1)
    menubar1.pack_start(rb13, False, False, 1)
    area.pack_start(menubar1, False, False, 2)

    menubar2.pack_start(label1, False, False, 5)
    menubar2.pack_start(entry1, False, False, 5)
    menubar2.pack_start(rb1, False, False, 1)
    menubar2.pack_start(rb2, False, False, 1)
    menubar2.pack_start(label2, False, False, 5)
    menubar2.pack_start(entry2, False, False, 5)
    menubar2.pack_start(rb3, False, False, 1)
    menubar2.pack_start(rb4, False, False, 1)
    menubar2.pack_end(button5, False, False, 5)
    area.pack_start(menubar2, False, False, 2)

    menubar3.pack_start(rb5, False, False, 1)
    menubar3.pack_start(rb6, False, False, 1)
    menubar3.pack_start(label4, False, False, 5)
    menubar3.pack_start(entry3, False, False, 5)
    menubar3.pack_start(label5, False, False, 5)
    menubar3.pack_start(entry4, False, False, 5)
    menubar3.pack_end(button6, False, False, 5)
    area.pack_start(menubar3, False, False, 2)


    chart = ChartDisplay()
    area.pack_end(chart, True, True, 0)
    window.add(area)

# Connect the events

    button1.connect("toggled", chart.callback, "night vision")
    button2.connect("toggled", chart.callback, "invert display")
    button3.connect("toggled", chart.callback, "flip horizontally")
    button4.connect("toggled", chart.callback, "draw constellations")
    button5.connect("clicked", chart.callback, "location change")
    rb1.connect("clicked", chart.callback, "rb1 clicked")
    rb2.connect("clicked", chart.callback, "rb2 clicked")
    rb3.connect("clicked", chart.callback, "rb3 clicked")
    rb4.connect("clicked", chart.callback, "rb4 clicked")
    rb5.connect("clicked", chart.callback, "rb5 clicked")
    rb6.connect("clicked", chart.callback, "rb6 clicked")
    rb7.connect("clicked", chart.callback, "rb7 clicked")
    rb8.connect("clicked", chart.callback, "rb8 clicked")
    rb9.connect("clicked", chart.callback, "rb9 clicked")
    rb10.connect("clicked", chart.callback, "rb10 clicked")
    rb11.connect("clicked", chart.callback, "rb11 clicked")
    rb12.connect("clicked", chart.callback, "rb12 clicked")
    rb13.connect("clicked", chart.callback, "rb13 clicked")
    button6.connect("clicked", chart.callback, "time change")
    chart.connect("expose_event", chart.area_expose_cb)

    initialize_controls()
    window.show_all()


def main():
    gtk.main()
    return 0

if __name__ == "__main__":
    MainChart()
    main()
